import ProxyEvent = require("../../../joynr/proxy/ProxyEvent");
import MessagingQos = require("../../../joynr/messaging/MessagingQos");
import JoynrDiscoveryQos = require("../../../joynr/proxy/DiscoveryQos");
import GlobalDiscoveryEntry = require("../../joynr/types/GlobalDiscoveryEntry");
declare namespace GlobalCapabilitiesDirectoryProxy {
    interface ProxySettings {
        domain: string;
        joynrName: string;
        discoveryQos: JoynrDiscoveryQos;
        messagingQos: MessagingQos | MessagingQos.Settings;
        dependencies: any;
        proxyParticipantId: string;
    }
    interface AddArgs1 {
        globalDiscoveryEntries: GlobalDiscoveryEntry[];
    }
    type AddReturns1 = void;
    interface AddArgs2 {
        globalDiscoveryEntry: GlobalDiscoveryEntry;
    }
    type AddReturns2 = void;
    interface AddArgs3 {
        globalDiscoveryEntry: GlobalDiscoveryEntry;
        gbids: string[];
    }
    type AddReturns3 = void;
    type AddSignature = ((settings: AddArgs1) => Promise<AddReturns1>) & ((settings: AddArgs2) => Promise<AddReturns2>) & ((settings: AddArgs3) => Promise<AddReturns3>);
    interface LookupArgs1 {
        domains: string[];
        interfaceName: string;
    }
    interface LookupReturns1 {
        result: GlobalDiscoveryEntry[];
    }
    interface LookupArgs2 {
        domains: string[];
        interfaceName: string;
        gbids: string[];
    }
    interface LookupReturns2 {
        result: GlobalDiscoveryEntry[];
    }
    interface LookupArgs3 {
        participantId: string;
    }
    interface LookupReturns3 {
        result: GlobalDiscoveryEntry;
    }
    interface LookupArgs4 {
        participantId: string;
        gbids: string[];
    }
    interface LookupReturns4 {
        result: GlobalDiscoveryEntry;
    }
    type LookupSignature = ((settings: LookupArgs1) => Promise<LookupReturns1>) & ((settings: LookupArgs2) => Promise<LookupReturns2>) & ((settings: LookupArgs3) => Promise<LookupReturns3>) & ((settings: LookupArgs4) => Promise<LookupReturns4>);
    interface RemoveStaleArgs1 {
        clusterControllerId: string;
        maxLastSeenDateMs: number;
    }
    type RemoveStaleReturns1 = void;
    type RemoveStaleSignature = ((settings: RemoveStaleArgs1) => Promise<RemoveStaleReturns1>);
    interface TouchArgs1 {
        clusterControllerId: string;
    }
    type TouchReturns1 = void;
    interface TouchArgs2 {
        clusterControllerId: string;
        participantIds: string[];
    }
    type TouchReturns2 = void;
    type TouchSignature = ((settings: TouchArgs1) => Promise<TouchReturns1>) & ((settings: TouchArgs2) => Promise<TouchReturns2>);
    interface RemoveArgs1 {
        participantIds: string[];
    }
    type RemoveReturns1 = void;
    interface RemoveArgs2 {
        participantId: string;
    }
    type RemoveReturns2 = void;
    interface RemoveArgs3 {
        participantId: string;
        gbids: string[];
    }
    type RemoveReturns3 = void;
    type RemoveSignature = ((settings: RemoveArgs1) => Promise<RemoveReturns1>) & ((settings: RemoveArgs2) => Promise<RemoveReturns2>) & ((settings: RemoveArgs3) => Promise<RemoveReturns3>);
}
/**
 * @classdesc
 * <br/>Generation date: Tue Dec 06 19:27:39 CET 2022
 * <br/><br/>
 * GlobalCapabilitiesDirectoryProxy, generated from the corresponding interface description.
 * <br/><br/>The GlobalCapabilitiesDirectory is a joynr internal interface. The joynr framework
 * uses it to register providers, which are available at a global scope, with the selected
 * backends.
 * Such global providers can be discovered by all cluster controllers which are connected to
 * the same GlobalCapabilitiesDirectory. In contrast, a provider that is available at local
 * scope only is solely registered at its own (local) cluster controller. It can only be
 * discovered by that cluster controller and runtimes connected to that cluster controller.
 * A provider is registered along with parameters which will be used during the arbitration
 * process to select a suitable provider for a proxy. This information is stored in
 * GlobalDiscoveryEntry objects. A provider/GlobalDiscoveryEntry can be registered in multiple
 * global backends, identified by its GBIDs (Global Backend Identifier). The lookup methods
 * always return only one GlobalDiscoveryEntry, i.e. a single GBID, for a provider which is
 * registered in multiple backends. The selection is up to the implementation of the Global
 * Capabilities Directory.
 * The reference to a GBID in the address field of GlobalDiscoveryEntries is not taken into
 * account in the add methods. It is replaced with the correct GBID in the return value of the
 * lookup methods, see description of the lookup methods. To make the add and lookup methods
 * of interface version 0.1 compatible with the new ones in version 0.2, each Global
 * Capabilities Directory instance must be available in only one global backend and it has to
 * know its own GBID.
 * #noVersionGeneration
 * @see GlobalDiscoveryEntry
 */
declare class GlobalCapabilitiesDirectoryProxy {
    interfaceName: string;
    settings: GlobalCapabilitiesDirectoryProxy.ProxySettings;
    domain: string;
    messagingQos: MessagingQos;
    /** set by ProxyBuilder after Arbitration **/
    providerDiscoveryEntry: {
        participantId: string;
    };
    proxyParticipantId: string;
    /**
     * @function GlobalCapabilitiesDirectoryProxy#add
     * @summary The add operation is GENERATED FROM THE INTERFACE DESCRIPTION
     * <br/>method overloading: different call semantics possible
     * <br/><br/>Registers several providers with the backend. The providers are registered
     * only in the global backend (GBID) of the Global Capabilities Directory instance which
     * received this call.
     *
     * @param {Object} settings the arguments object for this function call
     * @param {Array.<GlobalDiscoveryEntry>} settings.globalDiscoveryEntries -
     * A list which stores information about each provider instance that
     * shall be registered with the backend.<br/>GlobalDiscoveryEntry
     */
    /**
     * @function GlobalCapabilitiesDirectoryProxy#add
     * @summary The add operation is GENERATED FROM THE INTERFACE DESCRIPTION
     * <br/>method overloading: different call semantics possible
     * <br/><br/>Registers a single provider with the backend. The provider is registered with
     * the GBID of the Global Capabilities Directory instance which received this call.
     *
     * @param {Object} settings the arguments object for this function call
     * @param {GlobalDiscoveryEntry} settings.globalDiscoveryEntry -
     * Information about the provider which shall be registered with the
     * backend.<br/>GlobalDiscoveryEntry
     */
    /**
     * @function GlobalCapabilitiesDirectoryProxy#add
     * @summary The add operation is GENERATED FROM THE INTERFACE DESCRIPTION
     * <br/>method overloading: different call semantics possible
     * <br/><br/>Registers a single provider in the defined global backends
     *
     * @param {Object} settings the arguments object for this function call
     * @param {GlobalDiscoveryEntry} settings.globalDiscoveryEntry -
     * Information about the provider which shall be registered with the
     * backend.<br/>GlobalDiscoveryEntry
     * @param {Array.<String>} settings.gbids -
     * Global Backend IDs for which the provider is registered.
     */
    add: GlobalCapabilitiesDirectoryProxy.AddSignature;
    /**
     * @function GlobalCapabilitiesDirectoryProxy#lookup
     * @summary The lookup operation is GENERATED FROM THE INTERFACE DESCRIPTION
     * <br/>method overloading: different call semantics possible
     * <br/><br/>Looks up a list of providers for a list of domains and an interface name. The
     * domain and interface name correspond to the attributes stored in GlobalDiscoveryEntry.
     * The providers returned are registered to the same GBID as the Global Capabilities
     * Directory instance which received this call.
     * @see GlobalDiscoveryEntry
     *
     * @param {Object} settings the arguments object for this function call
     * @param {Array.<String>} settings.domains -
     * Domain names for which providers shall be returned.
     * @param {String} settings.interfaceName -
     * The name of the requested provider interface.
     * @returns {GlobalCapabilitiesDirectoryProxy#LookupReturned}
     * 	{Array.<GlobalDiscoveryEntry>} result
     */
    /**
     * @typedef {Object} GlobalCapabilitiesDirectoryProxy#LookupReturned
     * @property {Array.<GlobalDiscoveryEntry>} result
     * Information about all providers which were found for the given domains
     * and interface name in the backend of the Global Capabilities Directory instance.
     * If no matching providers are registered, an empty result list will be returned
     * (this is not an error).
     */
    /**
     * @function GlobalCapabilitiesDirectoryProxy#lookup
     * @summary The lookup operation is GENERATED FROM THE INTERFACE DESCRIPTION
     * <br/>method overloading: different call semantics possible
     * <br/><br/>Looks up a list of providers for a list of domains and an interface name in
     * the selected backends. The domain and interface name correspond to the attributes stored
     * in GlobalDiscoveryEntry.
     * Only one provider per participantId is returned. In case a single provider is registered
     * in multiple backends, only one GlobalDiscoveryEntry of that provider in a single backend
     * will be returned. The references to a GBID in the address fields of the returned
     * GlobalDiscoveryEntries have to be replaced with the selected GBID for each provider.
     * @see GlobalDiscoveryEntry
     *
     * @param {Object} settings the arguments object for this function call
     * @param {Array.<String>} settings.domains -
     * Domain names for which providers shall be returned.
     * @param {String} settings.interfaceName -
     * The name of the requested provider interface.
     * @param {Array.<String>} settings.gbids -
     * Global Backend IDs for which providers should be returned. Only
     * Providers from the provided Global Backends will be returned.
     * @returns {GlobalCapabilitiesDirectoryProxy#LookupReturned}
     * 	{Array.<GlobalDiscoveryEntry>} result
     */
    /**
     * @typedef {Object} GlobalCapabilitiesDirectoryProxy#LookupReturned
     * @property {Array.<GlobalDiscoveryEntry>} result
     * Information about all providers which were found for the given domain
     * and interface name in the provided backends (gbids). If none of the entries with
     * a matching domain and interface name has a matching GBID, the error
     * NO_ENTRY_FOR_SELECTED_BACKENDS will be returned.
     * If there are no matching providers at all, an empty result list will be returned
     * (this is not an error).
     */
    /**
     * @function GlobalCapabilitiesDirectoryProxy#lookup
     * @summary The lookup operation is GENERATED FROM THE INTERFACE DESCRIPTION
     * <br/>method overloading: different call semantics possible
     * <br/><br/>Looks up a provider for a given participant Id. The provider returned is
     * registered to the same GBID as the Global Capabilities Directory instance which
     * received this call.
     *
     * @param {Object} settings the arguments object for this function call
     * @param {String} settings.participantId -
     * The participant Id which identifies the requested provider.
     * @returns {GlobalCapabilitiesDirectoryProxy#LookupReturned}
     * 	{GlobalDiscoveryEntry} result
     */
    /**
     * @typedef {Object} GlobalCapabilitiesDirectoryProxy#LookupReturned
     * @property {GlobalDiscoveryEntry} result
     * Information about the found provider. If no matching provider is
     * registered, a ProviderRuntimeException will be returned.
     */
    /**
     * @function GlobalCapabilitiesDirectoryProxy#lookup
     * @summary The lookup operation is GENERATED FROM THE INTERFACE DESCRIPTION
     * <br/>method overloading: different call semantics possible
     * <br/><br/>Looks up a provider for a given participant Id in the selected backends.
     * In case the provider identified by the provided participantId is registered in
     * multiple backends, only one GlobalDiscoveryEntry of that provider in a single
     * backend will be returned. The references to a GBID in the address field of the
     * returned GlobalDiscoveryEntry has to be replaced with the selected GBID for the
     * provider.
     *
     * @param {Object} settings the arguments object for this function call
     * @param {String} settings.participantId -
     * The participant Id which identifies the requested provider.
     * @param {Array.<String>} settings.gbids -
     * Global Backend IDs for which the provider should be returned. The
     * provider is only returned if it is registered in one of the provided Global
     * Backends.
     * @returns {GlobalCapabilitiesDirectoryProxy#LookupReturned}
     * 	{GlobalDiscoveryEntry} result
     */
    /**
     * @typedef {Object} GlobalCapabilitiesDirectoryProxy#LookupReturned
     * @property {GlobalDiscoveryEntry} result
     * Information about the found provider. If none of the entries matching
     * the participantId has a matching GBID, the error NO_ENTRY_FOR_SELECTED_BACKENDS
     * will be returned. If there is no provider for this participantId,
     * NO_ENTRY_FOR_PARTICIPANT is returned.
     */
    lookup: GlobalCapabilitiesDirectoryProxy.LookupSignature;
    /**
     * @function GlobalCapabilitiesDirectoryProxy#removeStale
     * @summary The removeStale operation is GENERATED FROM THE INTERFACE DESCRIPTION
     * <br/><br/>Unregisters stale providers of a specific cluster controller which have been
     * registered in a previous cluster controller lifecycle from all backends. Only providers
     * with a lower last seen date than the provided maximum shall be removed.
     *
     * @param {Object} settings the arguments object for this function call
     * @param {String} settings.clusterControllerId -
     * Identifies the cluster controller for which GlobalDiscoveryEntries
     * shall be removed
     * @param {Number} settings.maxLastSeenDateMs -
     * The largest last seen date for entries to be removed. All entries
     * which have a lower last seen date shall be removed. All other entries have to
     * be kept.
     */
    removeStale: GlobalCapabilitiesDirectoryProxy.RemoveStaleSignature;
    /**
     * @function GlobalCapabilitiesDirectoryProxy#touch
     * @summary The touch operation is GENERATED FROM THE INTERFACE DESCRIPTION
     * <br/>method overloading: different call semantics possible
     * <br/><br/>Updates the last seen date of all GlobalDiscoveryEntries of a specific cluster
     * controller (in all backends).
     *
     * @param {Object} settings the arguments object for this function call
     * @param {String} settings.clusterControllerId -
     * Identifies the cluster controller for which the last seen date shall
     * be updated.
     */
    /**
     * @function GlobalCapabilitiesDirectoryProxy#touch
     * @summary The touch operation is GENERATED FROM THE INTERFACE DESCRIPTION
     * <br/>method overloading: different call semantics possible
     * <br/><br/>Updates the last seen date and the expiry date of the GlobalDiscoveryEntries
     * of a specific cluster controller (in all backends) which correspond to the provided list
     * of participant Ids. <br>
     * The last seen date will be set to the time of the touch call ('now'), the expiry date
     * will be extended, i.e. it will be set to 'now + N', where N is the configured default
     * provider / discovery entry expiry interval (6 weeks by default).
     *
     * @param {Object} settings the arguments object for this function call
     * @param {String} settings.clusterControllerId -
     * Identifies the cluster controller for which the last seen date and
     * the expiry date shall be updated.
     * @param {Array.<String>} settings.participantIds -
     * List of participantIds for which the last seen date and the expiry
     * date shall be updated in the correponding GlobalDiscoveryEntries.
     */
    touch: GlobalCapabilitiesDirectoryProxy.TouchSignature;
    /**
     * @function GlobalCapabilitiesDirectoryProxy#remove
     * @summary The remove operation is GENERATED FROM THE INTERFACE DESCRIPTION
     * <br/>method overloading: different call semantics possible
     * <br/><br/>Unregisters providers from the backend of the Global Capabilities Directory
     * instance which received this call.
     *
     * @param {Object} settings the arguments object for this function call
     * @param {Array.<String>} settings.participantIds -
     * The participand Ids which identify the providers that shall be removed
     * from the Global Capabilities Directory. This will remove the providers only from
     * the backend of the Global Capabilities Directory instance which received this
     * call.
     */
    /**
     * @function GlobalCapabilitiesDirectoryProxy#remove
     * @summary The remove operation is GENERATED FROM THE INTERFACE DESCRIPTION
     * <br/>method overloading: different call semantics possible
     * <br/><br/>Unregisters a provider from the backend of the Global Capabilities Directory
     * instance which received this call.
     *
     * @param {Object} settings the arguments object for this function call
     * @param {String} settings.participantId -
     * The participant Id which identifies the provider that shall be removed
     * from the Global Capabilities Directory. This will remove the provider only from
     * the backend of the Global Capabilities Directory instance which received this
     * call.
     */
    /**
     * @function GlobalCapabilitiesDirectoryProxy#remove
     * @summary The remove operation is GENERATED FROM THE INTERFACE DESCRIPTION
     * <br/>method overloading: different call semantics possible
     * <br/><br/>Unregisters a provider from the selected backends.
     *
     * @param {Object} settings the arguments object for this function call
     * @param {String} settings.participantId -
     * The participant Id which identifies the provider that shall be removed
     * from the Global Capabilities Directory. This will remove the provider from the
     * backends selected by the gbids parameter.
     * @param {Array.<String>} settings.gbids -
     * Global Backend IDs for which the selected provider shall be removed.
     */
    remove: GlobalCapabilitiesDirectoryProxy.RemoveSignature;
    /**
     * @name GlobalCapabilitiesDirectoryProxy#globalDiscoveryEntryChanged
     * @summary The globalDiscoveryEntryChanged event is GENERATED FROM THE INTERFACE DESCRIPTION
     * <br/><br/>[DEPRECATED (This broadcast has never been implemented and tested.)]
     * Event that is fired when a new GlobalDiscoveryEntry is added or an existing
     * entry is changed or removed. The event includes the affected GlobalDiscoveryEntry as
     * well as the type of change.
     * MULTICAST PARTITIONS:
     * This event is broadcasted using the following partition structure:
     * <domain> / <interface>
     */
    globalDiscoveryEntryChanged: ProxyEvent;
    /**
     * @param settings the settings object for this function call
     * @param settings.domain the domain name
     * @param settings.joynrName the interface name //TODO: check do we need this?
     *
     * @param settings.discoveryQos the Quality of Service parameters for arbitration
     * @param settings.discoveryQos.discoveryTimeoutMs for rpc calls to wait for arbitration to finish.
     * @param settings.discoveryQos.arbitrationStrategy Strategy for choosing the appropriate provider from the list returned by the capabilities directory
     * @param settings.discoveryQos.cacheMaxAgeMs Maximum age of entries in the localCapabilitiesDirectory. If this value filters out all entries of the local capabilities directory a lookup in the global capabilitiesDirectory will take place.
     * @param settings.discoveryQos.discoveryScope If localOnly is set to true, only local providers will be considered.
     * @param settings.discoveryQos.additionalParameters a map holding additional parameters in the form of key value pairs in the javascript object, e.g.: {"myKey": "myValue", "myKey2": 5}
     *
     * @param settings.messagingQos the Quality of Service parameters for messaging
     * @param settings.messagingQos.ttl Roundtrip timeout for rpc requests.
     * @param settings.dependencies instances of the internal objects needed by the proxy to interface with joynr
     * @param settings.proxyParticipantId unique identifier of the proxy
     */
    constructor(settings: GlobalCapabilitiesDirectoryProxy.ProxySettings);
    /**
     * The MAJOR_VERSION of the proxy is GENERATED FROM THE INTERFACE DESCRIPTION
     */
    static MAJOR_VERSION: number;
    /**
     * The MINOR_VERSION of the proxy is GENERATED FROM THE INTERFACE DESCRIPTION
     */
    static MINOR_VERSION: number;
    static getUsedJoynrtypes(): any[];
}
export = GlobalCapabilitiesDirectoryProxy;
