"use strict";
const ProxyOperation = require("../../../joynr/proxy/ProxyOperation");
const ProxyEvent = require("../../../joynr/proxy/ProxyEvent");
const MessagingQos = require("../../../joynr/messaging/MessagingQos");
const CustomParameter = require("../../joynr/types/CustomParameter");
const GlobalDiscoveryEntry = require("../../joynr/types/GlobalDiscoveryEntry");
const DiscoveryEntry = require("../../joynr/types/DiscoveryEntry");
const Version = require("../../joynr/types/Version");
const ChangeType = require("../../joynr/types/ChangeType");
const ProviderQos = require("../../joynr/types/ProviderQos");
const DiscoveryError = require("../../joynr/types/DiscoveryError");
const ProviderScope = require("../../joynr/types/ProviderScope");
/**
 * @classdesc
 * <br/>Generation date: Tue Dec 06 19:27:39 CET 2022
 * <br/><br/>
 * GlobalCapabilitiesDirectoryProxy, generated from the corresponding interface description.
 * <br/><br/>The GlobalCapabilitiesDirectory is a joynr internal interface. The joynr framework
 * uses it to register providers, which are available at a global scope, with the selected
 * backends.
 * Such global providers can be discovered by all cluster controllers which are connected to
 * the same GlobalCapabilitiesDirectory. In contrast, a provider that is available at local
 * scope only is solely registered at its own (local) cluster controller. It can only be
 * discovered by that cluster controller and runtimes connected to that cluster controller.
 * A provider is registered along with parameters which will be used during the arbitration
 * process to select a suitable provider for a proxy. This information is stored in
 * GlobalDiscoveryEntry objects. A provider/GlobalDiscoveryEntry can be registered in multiple
 * global backends, identified by its GBIDs (Global Backend Identifier). The lookup methods
 * always return only one GlobalDiscoveryEntry, i.e. a single GBID, for a provider which is
 * registered in multiple backends. The selection is up to the implementation of the Global
 * Capabilities Directory.
 * The reference to a GBID in the address field of GlobalDiscoveryEntries is not taken into
 * account in the add methods. It is replaced with the correct GBID in the return value of the
 * lookup methods, see description of the lookup methods. To make the add and lookup methods
 * of interface version 0.1 compatible with the new ones in version 0.2, each Global
 * Capabilities Directory instance must be available in only one global backend and it has to
 * know its own GBID.
 * #noVersionGeneration
 * @see GlobalDiscoveryEntry
 */
class GlobalCapabilitiesDirectoryProxy {
    /**
     * @param settings the settings object for this function call
     * @param settings.domain the domain name
     * @param settings.joynrName the interface name //TODO: check do we need this?
     *
     * @param settings.discoveryQos the Quality of Service parameters for arbitration
     * @param settings.discoveryQos.discoveryTimeoutMs for rpc calls to wait for arbitration to finish.
     * @param settings.discoveryQos.arbitrationStrategy Strategy for choosing the appropriate provider from the list returned by the capabilities directory
     * @param settings.discoveryQos.cacheMaxAgeMs Maximum age of entries in the localCapabilitiesDirectory. If this value filters out all entries of the local capabilities directory a lookup in the global capabilitiesDirectory will take place.
     * @param settings.discoveryQos.discoveryScope If localOnly is set to true, only local providers will be considered.
     * @param settings.discoveryQos.additionalParameters a map holding additional parameters in the form of key value pairs in the javascript object, e.g.: {"myKey": "myValue", "myKey2": 5}
     *
     * @param settings.messagingQos the Quality of Service parameters for messaging
     * @param settings.messagingQos.ttl Roundtrip timeout for rpc requests.
     * @param settings.dependencies instances of the internal objects needed by the proxy to interface with joynr
     * @param settings.proxyParticipantId unique identifier of the proxy
     */
    constructor(settings) {
        this.interfaceName = "infrastructure/GlobalCapabilitiesDirectory";
        this.domain = settings.domain;
        this.messagingQos = new MessagingQos(settings.messagingQos);
        this.proxyParticipantId = settings.proxyParticipantId;
        this.settings = settings;
        this.add = new ProxyOperation(this, "add", [
            {
                inputParameter: [
                    {
                        name: "globalDiscoveryEntries",
                        type: "joynr.types.GlobalDiscoveryEntry[]"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "globalDiscoveryEntry",
                        type: "joynr.types.GlobalDiscoveryEntry"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "globalDiscoveryEntry",
                        type: "joynr.types.GlobalDiscoveryEntry"
                    },
                    {
                        name: "gbids",
                        type: "String[]"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }
        ]).buildFunction();
        this.lookup = new ProxyOperation(this, "lookup", [
            {
                inputParameter: [
                    {
                        name: "domains",
                        type: "String[]"
                    },
                    {
                        name: "interfaceName",
                        type: "String"
                    }
                ],
                outputParameter: [
                    {
                        name: "result",
                        type: "joynr.types.GlobalDiscoveryEntry[]"
                    }
                ],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "domains",
                        type: "String[]"
                    },
                    {
                        name: "interfaceName",
                        type: "String"
                    },
                    {
                        name: "gbids",
                        type: "String[]"
                    }
                ],
                outputParameter: [
                    {
                        name: "result",
                        type: "joynr.types.GlobalDiscoveryEntry[]"
                    }
                ],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "participantId",
                        type: "String"
                    }
                ],
                outputParameter: [
                    {
                        name: "result",
                        type: "joynr.types.GlobalDiscoveryEntry"
                    }
                ],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "participantId",
                        type: "String"
                    },
                    {
                        name: "gbids",
                        type: "String[]"
                    }
                ],
                outputParameter: [
                    {
                        name: "result",
                        type: "joynr.types.GlobalDiscoveryEntry"
                    }
                ],
                fireAndForget: false
            }
        ]).buildFunction();
        this.removeStale = new ProxyOperation(this, "removeStale", [
            {
                inputParameter: [
                    {
                        name: "clusterControllerId",
                        type: "String"
                    },
                    {
                        name: "maxLastSeenDateMs",
                        type: "Long"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }
        ]).buildFunction();
        this.touch = new ProxyOperation(this, "touch", [
            {
                inputParameter: [
                    {
                        name: "clusterControllerId",
                        type: "String"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "clusterControllerId",
                        type: "String"
                    },
                    {
                        name: "participantIds",
                        type: "String[]"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }
        ]).buildFunction();
        this.remove = new ProxyOperation(this, "remove", [
            {
                inputParameter: [
                    {
                        name: "participantIds",
                        type: "String[]"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "participantId",
                        type: "String"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "participantId",
                        type: "String"
                    },
                    {
                        name: "gbids",
                        type: "String[]"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }
        ]).buildFunction();
        /**
         * @name GlobalCapabilitiesDirectoryProxy#globalDiscoveryEntryChanged
         * @summary The globalDiscoveryEntryChanged event is GENERATED FROM THE INTERFACE DESCRIPTION
         * <br/><br/>[DEPRECATED (This broadcast has never been implemented and tested.)]
         * Event that is fired when a new GlobalDiscoveryEntry is added or an existing
         * entry is changed or removed. The event includes the affected GlobalDiscoveryEntry as
         * well as the type of change.
         * MULTICAST PARTITIONS:
         * This event is broadcasted using the following partition structure:
         * <domain> / <interface>
         */
        this.globalDiscoveryEntryChanged = new ProxyEvent(this, {
            broadcastName: "globalDiscoveryEntryChanged",
            broadcastParameter: [
                {
                    name: "typeOfChange",
                    type: "joynr.types.ChangeType"
                },
                {
                    name: "globalDiscoveryEntry",
                    type: "joynr.types.GlobalDiscoveryEntry"
                }
            ],
            messagingQos: this.messagingQos,
            discoveryQos: settings.discoveryQos,
            dependencies: {
                subscriptionManager: settings.dependencies.subscriptionManager
            }
        });
    }
    static getUsedJoynrtypes() {
        return [
            CustomParameter,
            GlobalDiscoveryEntry,
            DiscoveryEntry,
            Version,
            ChangeType,
            ProviderQos,
            DiscoveryError,
            ProviderScope
        ];
    }
}
/**
 * The MAJOR_VERSION of the proxy is GENERATED FROM THE INTERFACE DESCRIPTION
 */
GlobalCapabilitiesDirectoryProxy.MAJOR_VERSION = 0;
/**
 * The MINOR_VERSION of the proxy is GENERATED FROM THE INTERFACE DESCRIPTION
 */
GlobalCapabilitiesDirectoryProxy.MINOR_VERSION = 3;
module.exports = GlobalCapabilitiesDirectoryProxy;
