"use strict";
const ProxyOperation = require("../../../joynr/proxy/ProxyOperation");
const MessagingQos = require("../../../joynr/messaging/MessagingQos");
const DiscoveryEntry = require("../../joynr/types/DiscoveryEntry");
const CustomParameter = require("../../joynr/types/CustomParameter");
const DiscoveryEntryWithMetaInfo = require("../../joynr/types/DiscoveryEntryWithMetaInfo");
const Version = require("../../joynr/types/Version");
const ProviderQos = require("../../joynr/types/ProviderQos");
const DiscoveryError = require("../../joynr/types/DiscoveryError");
const DiscoveryQos = require("../../joynr/types/DiscoveryQos");
const DiscoveryScope = require("../../joynr/types/DiscoveryScope");
const ProviderScope = require("../../joynr/types/ProviderScope");
/**
 * @classdesc
 * <br/>Generation date: Tue Dec 06 19:27:38 CET 2022
 * <br/><br/>
 * DiscoveryProxy, generated from the corresponding interface description.
 * <br/><br/>The <code>Discovery</code> interface is a joynr internal
 * interface. This interface is used by libjoynr to add, lookup or
 * remove provider to joynr discovery. Internally joynr discovery
 * consists of a centralized discovery directory
 * (<code>GlobalCapabilitiesDirectory</code>) that is distributed to
 * all cluster controller (<code>LocalCapabilitiesDirectory</code>).
 * #noVersionGeneration
 */
class DiscoveryProxy {
    /**
     * @param settings the settings object for this function call
     * @param settings.domain the domain name
     * @param settings.joynrName the interface name //TODO: check do we need this?
     *
     * @param settings.discoveryQos the Quality of Service parameters for arbitration
     * @param settings.discoveryQos.discoveryTimeoutMs for rpc calls to wait for arbitration to finish.
     * @param settings.discoveryQos.arbitrationStrategy Strategy for choosing the appropriate provider from the list returned by the capabilities directory
     * @param settings.discoveryQos.cacheMaxAgeMs Maximum age of entries in the localCapabilitiesDirectory. If this value filters out all entries of the local capabilities directory a lookup in the global capabilitiesDirectory will take place.
     * @param settings.discoveryQos.discoveryScope If localOnly is set to true, only local providers will be considered.
     * @param settings.discoveryQos.additionalParameters a map holding additional parameters in the form of key value pairs in the javascript object, e.g.: {"myKey": "myValue", "myKey2": 5}
     *
     * @param settings.messagingQos the Quality of Service parameters for messaging
     * @param settings.messagingQos.ttl Roundtrip timeout for rpc requests.
     * @param settings.dependencies instances of the internal objects needed by the proxy to interface with joynr
     * @param settings.proxyParticipantId unique identifier of the proxy
     */
    constructor(settings) {
        this.interfaceName = "system/Discovery";
        this.domain = settings.domain;
        this.messagingQos = new MessagingQos(settings.messagingQos);
        this.proxyParticipantId = settings.proxyParticipantId;
        this.settings = settings;
        this.add = new ProxyOperation(this, "add", [
            {
                inputParameter: [
                    {
                        name: "discoveryEntry",
                        type: "joynr.types.DiscoveryEntry"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "discoveryEntry",
                        type: "joynr.types.DiscoveryEntry"
                    },
                    {
                        name: "awaitGlobalRegistration",
                        type: "Boolean"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "discoveryEntry",
                        type: "joynr.types.DiscoveryEntry"
                    },
                    {
                        name: "awaitGlobalRegistration",
                        type: "Boolean"
                    },
                    {
                        name: "gbids",
                        type: "String[]"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }
        ]).buildFunction();
        this.lookup = new ProxyOperation(this, "lookup", [
            {
                inputParameter: [
                    {
                        name: "domains",
                        type: "String[]"
                    },
                    {
                        name: "interfaceName",
                        type: "String"
                    },
                    {
                        name: "discoveryQos",
                        type: "joynr.types.DiscoveryQos"
                    }
                ],
                outputParameter: [
                    {
                        name: "result",
                        type: "joynr.types.DiscoveryEntryWithMetaInfo[]"
                    }
                ],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "domains",
                        type: "String[]"
                    },
                    {
                        name: "interfaceName",
                        type: "String"
                    },
                    {
                        name: "discoveryQos",
                        type: "joynr.types.DiscoveryQos"
                    },
                    {
                        name: "gbids",
                        type: "String[]"
                    }
                ],
                outputParameter: [
                    {
                        name: "result",
                        type: "joynr.types.DiscoveryEntryWithMetaInfo[]"
                    }
                ],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "participantId",
                        type: "String"
                    }
                ],
                outputParameter: [
                    {
                        name: "result",
                        type: "joynr.types.DiscoveryEntryWithMetaInfo"
                    }
                ],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "participantId",
                        type: "String"
                    },
                    {
                        name: "discoveryQos",
                        type: "joynr.types.DiscoveryQos"
                    },
                    {
                        name: "gbids",
                        type: "String[]"
                    }
                ],
                outputParameter: [
                    {
                        name: "result",
                        type: "joynr.types.DiscoveryEntryWithMetaInfo"
                    }
                ],
                fireAndForget: false
            }
        ]).buildFunction();
        this.addToAll = new ProxyOperation(this, "addToAll", [
            {
                inputParameter: [
                    {
                        name: "discoveryEntry",
                        type: "joynr.types.DiscoveryEntry"
                    },
                    {
                        name: "awaitGlobalRegistration",
                        type: "Boolean"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }
        ]).buildFunction();
        this.remove = new ProxyOperation(this, "remove", [
            {
                inputParameter: [
                    {
                        name: "participantId",
                        type: "String"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }
        ]).buildFunction();
    }
    static getUsedJoynrtypes() {
        return [
            DiscoveryEntry,
            CustomParameter,
            DiscoveryEntryWithMetaInfo,
            Version,
            ProviderQos,
            DiscoveryError,
            DiscoveryQos,
            DiscoveryScope,
            ProviderScope
        ];
    }
}
/**
 * The MAJOR_VERSION of the proxy is GENERATED FROM THE INTERFACE DESCRIPTION
 */
DiscoveryProxy.MAJOR_VERSION = 0;
/**
 * The MINOR_VERSION of the proxy is GENERATED FROM THE INTERFACE DESCRIPTION
 */
DiscoveryProxy.MINOR_VERSION = 3;
module.exports = DiscoveryProxy;
