"use strict";
const ProxyAttribute_1 = require("../../../joynr/proxy/ProxyAttribute");
const ProxyOperation = require("../../../joynr/proxy/ProxyOperation");
const MessagingQos = require("../../../joynr/messaging/MessagingQos");
const WebSocketClientAddress = require("../../joynr/system/RoutingTypes/WebSocketClientAddress");
const BrowserAddress = require("../../joynr/system/RoutingTypes/BrowserAddress");
const WebSocketAddress = require("../../joynr/system/RoutingTypes/WebSocketAddress");
const WebSocketProtocol = require("../../joynr/system/RoutingTypes/WebSocketProtocol");
const MqttAddress = require("../../joynr/system/RoutingTypes/MqttAddress");
const ChannelAddress = require("../../joynr/system/RoutingTypes/ChannelAddress");
const UdsAddress = require("../../joynr/system/RoutingTypes/UdsAddress");
const Address = require("../../joynr/system/RoutingTypes/Address");
const LocalAddress = require("../../joynr/system/RoutingTypes/LocalAddress");
const UdsClientAddress = require("../../joynr/system/RoutingTypes/UdsClientAddress");
const BinderAddress = require("../../joynr/system/RoutingTypes/BinderAddress");
/**
 * @classdesc
 * <br/>Generation date: Tue Dec 06 19:27:38 CET 2022
 * <br/><br/>
 * RoutingProxy, generated from the corresponding interface description.
 * <br/><br/>The <code>Routing</code> interface is a joynr internal
 * interface. joynr uses a hierarchy of <code>MessageRouter</code>s to
 * route messages from source to destination. The <code>Routing</code>
 * interface is used to update routing information between parent and
 * child <code>MessageRouter</code>s.
 * #noVersionGeneration
 */
class RoutingProxy {
    /**
     * @param settings the settings object for this function call
     * @param settings.domain the domain name
     * @param settings.joynrName the interface name //TODO: check do we need this?
     *
     * @param settings.discoveryQos the Quality of Service parameters for arbitration
     * @param settings.discoveryQos.discoveryTimeoutMs for rpc calls to wait for arbitration to finish.
     * @param settings.discoveryQos.arbitrationStrategy Strategy for choosing the appropriate provider from the list returned by the capabilities directory
     * @param settings.discoveryQos.cacheMaxAgeMs Maximum age of entries in the localCapabilitiesDirectory. If this value filters out all entries of the local capabilities directory a lookup in the global capabilitiesDirectory will take place.
     * @param settings.discoveryQos.discoveryScope If localOnly is set to true, only local providers will be considered.
     * @param settings.discoveryQos.additionalParameters a map holding additional parameters in the form of key value pairs in the javascript object, e.g.: {"myKey": "myValue", "myKey2": 5}
     *
     * @param settings.messagingQos the Quality of Service parameters for messaging
     * @param settings.messagingQos.ttl Roundtrip timeout for rpc requests.
     * @param settings.dependencies instances of the internal objects needed by the proxy to interface with joynr
     * @param settings.proxyParticipantId unique identifier of the proxy
     */
    constructor(settings) {
        this.interfaceName = "system/Routing";
        this.domain = settings.domain;
        this.messagingQos = new MessagingQos(settings.messagingQos);
        this.proxyParticipantId = settings.proxyParticipantId;
        this.settings = settings;
        this.globalAddress = new ProxyAttribute_1.ProxyReadNotifyAttribute(this, "globalAddress", "String");
        this.replyToAddress = new ProxyAttribute_1.ProxyReadNotifyAttribute(this, "replyToAddress", "String");
        this.addNextHop = new ProxyOperation(this, "addNextHop", [
            {
                inputParameter: [
                    {
                        name: "participantId",
                        type: "String"
                    },
                    {
                        name: "channelAddress",
                        type: "joynr.system.RoutingTypes.ChannelAddress"
                    },
                    {
                        name: "isGloballyVisible",
                        type: "Boolean"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "participantId",
                        type: "String"
                    },
                    {
                        name: "mqttAddress",
                        type: "joynr.system.RoutingTypes.MqttAddress"
                    },
                    {
                        name: "isGloballyVisible",
                        type: "Boolean"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "participantId",
                        type: "String"
                    },
                    {
                        name: "browserAddress",
                        type: "joynr.system.RoutingTypes.BrowserAddress"
                    },
                    {
                        name: "isGloballyVisible",
                        type: "Boolean"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "participantId",
                        type: "String"
                    },
                    {
                        name: "webSocketAddress",
                        type: "joynr.system.RoutingTypes.WebSocketAddress"
                    },
                    {
                        name: "isGloballyVisible",
                        type: "Boolean"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "participantId",
                        type: "String"
                    },
                    {
                        name: "udsAddress",
                        type: "joynr.system.RoutingTypes.UdsAddress"
                    },
                    {
                        name: "isGloballyVisible",
                        type: "Boolean"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "participantId",
                        type: "String"
                    },
                    {
                        name: "binderAddress",
                        type: "joynr.system.RoutingTypes.BinderAddress"
                    },
                    {
                        name: "isGloballyVisible",
                        type: "Boolean"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "participantId",
                        type: "String"
                    },
                    {
                        name: "webSocketClientAddress",
                        type: "joynr.system.RoutingTypes.WebSocketClientAddress"
                    },
                    {
                        name: "isGloballyVisible",
                        type: "Boolean"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }, {
                inputParameter: [
                    {
                        name: "participantId",
                        type: "String"
                    },
                    {
                        name: "udsClientAddress",
                        type: "joynr.system.RoutingTypes.UdsClientAddress"
                    },
                    {
                        name: "isGloballyVisible",
                        type: "Boolean"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }
        ]).buildFunction();
        this.resolveNextHop = new ProxyOperation(this, "resolveNextHop", [
            {
                inputParameter: [
                    {
                        name: "participantId",
                        type: "String"
                    }
                ],
                outputParameter: [
                    {
                        name: "resolved",
                        type: "Boolean"
                    }
                ],
                fireAndForget: false
            }
        ]).buildFunction();
        this.removeNextHop = new ProxyOperation(this, "removeNextHop", [
            {
                inputParameter: [
                    {
                        name: "participantId",
                        type: "String"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }
        ]).buildFunction();
        this.addMulticastReceiver = new ProxyOperation(this, "addMulticastReceiver", [
            {
                inputParameter: [
                    {
                        name: "multicastId",
                        type: "String"
                    },
                    {
                        name: "subscriberParticipantId",
                        type: "String"
                    },
                    {
                        name: "providerParticipantId",
                        type: "String"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }
        ]).buildFunction();
        this.removeMulticastReceiver = new ProxyOperation(this, "removeMulticastReceiver", [
            {
                inputParameter: [
                    {
                        name: "multicastId",
                        type: "String"
                    },
                    {
                        name: "subscriberParticipantId",
                        type: "String"
                    },
                    {
                        name: "providerParticipantId",
                        type: "String"
                    }
                ],
                outputParameter: [],
                fireAndForget: false
            }
        ]).buildFunction();
    }
    static getUsedJoynrtypes() {
        return [
            WebSocketClientAddress,
            BrowserAddress,
            WebSocketAddress,
            WebSocketProtocol,
            MqttAddress,
            ChannelAddress,
            UdsAddress,
            Address,
            LocalAddress,
            UdsClientAddress,
            BinderAddress
        ];
    }
}
/**
 * The MAJOR_VERSION of the proxy is GENERATED FROM THE INTERFACE DESCRIPTION
 */
RoutingProxy.MAJOR_VERSION = 0;
/**
 * The MINOR_VERSION of the proxy is GENERATED FROM THE INTERFACE DESCRIPTION
 */
RoutingProxy.MINOR_VERSION = 1;
module.exports = RoutingProxy;
