"use strict";
const DiscoveryEntry = require("./DiscoveryEntry");
/**
 * This is the generated struct type GlobalDiscoveryEntry: DOCS GENERATED FROM INTERFACE DESCRIPTION
 * <br/>Generation date: Tue Dec 06 19:27:39 CET 2022
 * <br/><br/>GlobalDiscoveryEntry stores information about a provider instance and extends
 * DiscoveryEntry by adding transport middleware specific address information.
 * GlobalDiscoveryEntry objects are used to register a new provider instance with the backend.
 * In addition, objects of GlobalDiscoveryEntry will be returned by the backend during the
 * arbitration process in order to select a suitable provider for a proxy.
 * @see DiscoveryEntry
 */
class GlobalDiscoveryEntry extends DiscoveryEntry {
    /**
     * @param members - an object containing the individual member elements
     * @param members.providerVersion - semantic version information
     * @param members.domain - the domain to register the provider with
     * @param members.interfaceName - the name of the provider interface
     * @param members.participantId - the participant ID of the provider
     * @param members.qos - the qos of the provider
     * @param members.lastSeenDateMs - the date in millis since epoch when the source for this provider last
     * 			contacted the directory
     * @param members.expiryDateMs - the date in millis since epoch when this entry can be purged from the
     * 			directory and caches
     * @param members.publicKeyId - the ID of the public key to be used to encrypt messages to
     * 		this provider
     * @param members.address - the serialized transport-middleware-specific address where the provider can
     * 			be reached. The address is a subclass of <code>Address</code> and is stored as a JSON string.
     */
    constructor(members) {
        super(members);
        this._typeName = "joynr.types.GlobalDiscoveryEntry";
        if (members) {
            this.address = members.address;
        }
    }
    static checkMembers(_instance, _check) {
        _check(_instance.providerVersion, "Version", "members.providerVersion");
        _check(_instance.domain, "String", "members.domain");
        _check(_instance.interfaceName, "String", "members.interfaceName");
        _check(_instance.participantId, "String", "members.participantId");
        _check(_instance.qos, "ProviderQos", "members.qos");
        _check(_instance.lastSeenDateMs, "Number", "members.lastSeenDateMs");
        _check(_instance.expiryDateMs, "Number", "members.expiryDateMs");
        _check(_instance.publicKeyId, "String", "members.publicKeyId");
        _check(_instance.address, "String", "members.address");
    }
    static getMemberType(memberName) {
        if (GlobalDiscoveryEntry._memberTypes[memberName] !== undefined) {
            return GlobalDiscoveryEntry._memberTypes[memberName];
        }
    }
}
GlobalDiscoveryEntry._typeName = "joynr.types.GlobalDiscoveryEntry";
/**
 * The MAJOR_VERSION of the struct type GlobalDiscoveryEntry is GENERATED FROM THE INTERFACE DESCRIPTION
 */
GlobalDiscoveryEntry.MAJOR_VERSION = 0;
/**
 * The MINOR_VERSION of the struct type GlobalDiscoveryEntry is GENERATED FROM THE INTERFACE DESCRIPTION
 */
GlobalDiscoveryEntry.MINOR_VERSION = 0;
GlobalDiscoveryEntry._memberTypes = {
    providerVersion: "joynr.types.Version",
    domain: "String",
    interfaceName: "String",
    participantId: "String",
    qos: "joynr.types.ProviderQos",
    lastSeenDateMs: "Long",
    expiryDateMs: "Long",
    publicKeyId: "String",
    address: "String"
};
module.exports = GlobalDiscoveryEntry;
