import { InProcessProvisioning, Provisioning, UdsLibJoynrProvisioning, WebSocketLibjoynrProvisioning } from "./joynr/start/interface/Provisioning";
import JoynrObject from "./joynr/types/JoynrObject";
import JoynrRuntime = require("./joynr/start/JoynrRuntime");
import JoynrApi = require("./libjoynr-deps");
import TypeRegistry = require("./joynr/start/TypeRegistry");
import ProxyBuilder = require("./joynr/proxy/ProxyBuilder");
import ProviderBuilder = require("./joynr/provider/ProviderBuilder");
import loggingManager = require("./joynr/system/LoggingManager");
import ParticipantIdStorage = require("./joynr/capabilities/ParticipantIdStorage");
import CapabilitiesRegistrar = require("./joynr/capabilities/CapabilitiesRegistrar");
import JoynrRuntimeException from "./joynr/exceptions/JoynrRuntimeException";
interface Type<T> extends Function {
    new (...args: any[]): T;
}
declare type JoynrKeys = "shutdown" | "terminateAllSubscriptions" | "registration" | "providerBuilder" | "proxyBuilder" | "participantIdStorage" | "logging" | "typeRegistry";
declare class Joynr extends JoynrApi implements Pick<JoynrRuntime<Provisioning>, JoynrKeys> {
    logging: loggingManager;
    participantIdStorage: ParticipantIdStorage;
    providerBuilder: ProviderBuilder;
    proxyBuilder: ProxyBuilder;
    registration: CapabilitiesRegistrar;
    typeRegistry: TypeRegistry;
    shutdown: (settings?: any) => Promise<any>;
    terminateAllSubscriptions: (timeout?: number) => Promise<any>;
    private loaded;
    JoynrObject: typeof JoynrObject;
    private selectedRuntime;
    /**
     * @param provisioning
     * @param onFatalRuntimeError Called in case a runtime error prevents further communication
     * @return Promise object being resolved in case all libjoynr dependencies are loaded
     */
    load(provisioning: UdsLibJoynrProvisioning | InProcessProvisioning | WebSocketLibjoynrProvisioning, onFatalRuntimeError?: (error: JoynrRuntimeException) => void): Promise<Joynr>;
    /**
     * Changes the selected default joynr runtime from websocket to the passed runtime
     *
     * @param runtime child class of JoynrRuntime
     * @returns joynr for easy chaining
     */
    selectRuntime(runtime: Type<JoynrRuntime<any>>): joynr;
}
declare type joynr = Joynr;
declare const joynr: Joynr;
export = joynr;
