"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
const CapabilitiesUtil = __importStar(require("../util/CapabilitiesUtil"));
class ParticipantIdStorage {
    /**
     * @constructor
     *
     * @param persistency - the persistence object to be used to store the participantIds
     * @param createUniqueId - a function generating a unique string
     */
    constructor(persistency, createUniqueId) {
        this.persistency = persistency;
        this.createUniqueId = createUniqueId;
    }
    /**
     * @param domain
     * @param provider
     * @param provider.interfaceName
     *
     * @returns the retrieved or generated participantId
     */
    getParticipantId(domain, provider) {
        const key = CapabilitiesUtil.generateParticipantIdStorageKey(domain, provider.interfaceName, provider.constructor.MAJOR_VERSION);
        let participantId = this.persistency.getItem(key);
        if (!participantId) {
            participantId = this.createUniqueId();
            this.persistency.setItem(key, participantId);
        }
        return participantId;
    }
    /**
     * @param domain
     * @param provider
     * @param provider.interfaceName
     * @param participantId
     */
    setParticipantId(domain, provider, participantId) {
        const key = CapabilitiesUtil.generateParticipantIdStorageKey(domain, provider.interfaceName, provider.constructor.MAJOR_VERSION);
        this.persistency.setItem(key, participantId);
    }
}
module.exports = ParticipantIdStorage;
