import * as DiscoveryEntryWithMetaInfo from "../../../generated/joynr/types/DiscoveryEntryWithMetaInfo";
import * as Version from "../../../generated/joynr/types/Version";
import { DiscoveryStub } from "../interface/DiscoveryStub";
import DiscoveryQos = require("../../proxy/DiscoveryQos");
declare class Arbitrator {
    private started;
    private arbitrationId;
    private pendingArbitrations;
    private capabilityDiscoveryStub;
    private staticCapabilities?;
    /**
     * An arbitrator looks up all capabilities for given domains and an interface and uses the provides arbitraionStrategy passed in the
     * discoveryQos to choose one or more for the calling proxy
     *
     * @constructor
     *
     * @param capabilityDiscoveryStub the capability discovery
     * @param staticCapabilities the capabilities the arbitrator will use to resolve capabilities in case of static arbitration
     */
    constructor(capabilityDiscoveryStub: DiscoveryStub, staticCapabilities?: DiscoveryEntryWithMetaInfo[]);
    /**
     * Starts the arbitration process
     *
     * @param settings the settings object
     * @param settings.domains the domains to discover the provider
     * @param settings.interfaceName the interfaceName to discover the provider
     * @param settings.discoveryQos
     * @param [settings.staticArbitration] shall the arbitrator use staticCapabilities or contact the discovery provider
     * @param [settings.proxyVersion] the version of the proxy object
     *
     * @returns Promise
     *  - resolved with an array of arbitrated capabilities
     *  - rejected with either DiscoveryException or NoCompatibleProviderFoundException
     */
    startArbitration(settings: {
        domains: string[];
        interfaceName: string;
        discoveryQos: DiscoveryQos;
        staticArbitration?: boolean;
        proxyVersion: Version;
        gbids?: string[];
    }): Promise<any[]>;
    /**
     * checks if the provided discoveryEntry supports onChange subscriptions if required
     *
     * @param discoveryEntry - the discovery entry to check
     * @param providerMustSupportOnChange - filter only entries supporting onChange subscriptions
     */
    private static checkSupportsOnChangeSubscriptions;
    private discoverCapabilitiesWrapper;
    /**
     * Tries to discover capabilities with given domains, interfaceName and discoveryQos within the localCapDir as long as the deferred's state is pending
     *
     * @param capabilityDiscoveryStub - the capabilites discovery module
     * @param domains - the domains
     * @param interfaceName - the interfaceName
     * @param applicationDiscoveryQos
     * @param proxyVersion
     * @param gbids global backend identifiers of backends to look for capabilities
     * @returns a Promise/A+ object, that will provide an array of discovered capabilities
     */
    private discoverCapabilities;
    private discoverStaticCapabilities;
    /**
     * Shutdown the Arbitrator
     */
    shutdown(): void;
}
export = Arbitrator;
