"use strict";
/*
 * #%L
 * %%
 * Copyright (C) 2019 BMW Car IT GmbH
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const MessagingQos_1 = __importDefault(require("../../messaging/MessagingQos"));
class LocalDiscoveryAggregator {
    constructor() {
        // Epsilon is added to be sure that the proxy call `lookup` gets results, whatever it is rather than timing out with
        // JoynrTimeoutException. By adding this epsilon, we avoid race condition between local expiration timer and the
        // delivery of the reply.
        this.epsilonMs = 10000;
        // do nothing
    }
    setDiscoveryProxy(discoveryProxy) {
        this.discoveryProxy = discoveryProxy;
        this.defaultMessagingQos = this.discoveryProxy.messagingQos;
    }
    setDiscoveryProxyTtl(ttl) {
        const qos = new MessagingQos_1.default(this.defaultMessagingQos);
        qos.ttl = ttl;
        this.discoveryProxy.messagingQos = qos;
    }
    restoreDefaultMessagingQos() {
        this.discoveryProxy.messagingQos = this.defaultMessagingQos;
    }
    lookupByParticipantId(participantId, discoveryQos, gbids) {
        // remaining discovery time + epsilon
        const ttl = discoveryQos.discoveryTimeout + this.epsilonMs;
        this.setDiscoveryProxyTtl(ttl);
        const promise = this.discoveryProxy
            .lookup({
            participantId,
            discoveryQos,
            gbids
        })
            .then(opArgs => {
            return opArgs.result;
        });
        this.restoreDefaultMessagingQos();
        return promise;
    }
    lookup(domains, interfaceName, discoveryQos, gbids) {
        // remaining discovery time + epsilon
        const ttl = discoveryQos.discoveryTimeout + this.epsilonMs;
        this.setDiscoveryProxyTtl(ttl);
        const promise = this.discoveryProxy
            .lookup({
            domains,
            interfaceName,
            discoveryQos,
            gbids
        })
            .then(opArgs => {
            return opArgs.result;
        });
        this.restoreDefaultMessagingQos();
        return promise;
    }
    add(discoveryEntry, awaitGlobalRegistration, gbids) {
        return this.discoveryProxy.add({
            discoveryEntry,
            awaitGlobalRegistration,
            gbids
        });
    }
    addToAll(discoveryEntry, awaitGlobalRegistration) {
        return this.discoveryProxy.addToAll({
            discoveryEntry,
            awaitGlobalRegistration
        });
    }
    remove(participantId) {
        return this.discoveryProxy.remove({
            participantId
        });
    }
}
module.exports = LocalDiscoveryAggregator;
