import MulticastSubscriptionRequest = require("./MulticastSubscriptionRequest");
import BroadcastSubscriptionRequest = require("./BroadcastSubscriptionRequest");
import BroadcastFilterParameters = require("../../proxy/BroadcastFilterParameters");
import SubscriptionQos = require("../../proxy/SubscriptionQos");
import SubscriptionRequest = require("./SubscriptionRequest");
import MulticastSubscriptionQos = require("../../proxy/MulticastSubscriptionQos");
import OnChangeSubscriptionQos = require("../../proxy/OnChangeSubscriptionQos");
import OnChangeWithKeepAliveSubscriptionQos = require("../../proxy/OnChangeWithKeepAliveSubscriptionQos");
import PeriodicSubscriptionQos from "../../proxy/PeriodicSubscriptionQos";
declare type SubscriptionType = "subscription_type_multicast" | "subscription_type_broadcast" | "subscription_type_attribute";
declare class SubscriptionInformation {
    static SUBSCRIPTION_TYPE_MULTICAST: "subscription_type_multicast";
    static SUBSCRIPTION_TYPE_BROADCAST: "subscription_type_broadcast";
    static SUBSCRIPTION_TYPE_ATTRIBUTE: "subscription_type_attribute";
    qos: SubscriptionQos & MulticastSubscriptionQos & OnChangeSubscriptionQos & OnChangeWithKeepAliveSubscriptionQos & PeriodicSubscriptionQos;
    subscribedToName: string;
    subscriptionId: string;
    providerParticipantId: string;
    proxyParticipantId: string;
    subscriptionType: SubscriptionType;
    multicastId?: string;
    lastPublication?: number;
    filterParameters?: BroadcastFilterParameters;
    _typeName: string;
    /** Return type due to LongTimer.setTimeout */
    subscriptionInterval?: string | number;
    endDateTimeout?: string | number;
    /** Return type due to LongTimer.setTimeout */
    onChangeDebounce?: string | number;
    /**
     * @constructor
     * @param subscriptionType
     * @param proxyParticipantId Id of the proxy
     * @param providerParticipantId Id of the provider
     * @param [request] the subscription request
     */
    constructor(subscriptionType: "subscription_type_multicast", proxyParticipantId: string, providerParticipantId: string, request: MulticastSubscriptionRequest);
    constructor(subscriptionType: "subscription_type_broadcast", proxyParticipantId: string, providerParticipantId: string, request: BroadcastSubscriptionRequest);
    constructor(subscriptionType: "subscription_type_attribute", proxyParticipantId: string, providerParticipantId: string, request: SubscriptionRequest);
}
export = SubscriptionInformation;
