"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
/*
 * #%L
 * %%
 * Copyright (C) 2019 BMW Car IT GmbH
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
const UtilInternal_1 = require("../util/UtilInternal");
const JoynrException_1 = __importDefault(require("./JoynrException"));
const defaultMessage = "ApplicationException with error: ";
class ApplicationException extends JoynrException_1.default {
    /**
     * Constructor of ApplicationException object used for reporting
     * error conditions from method implementations. The settings.error
     * object must be filled with _typeName and name as serialization
     * of an enum object of the matching error enum type defined in
     * Franca.
     *
     * @param [settings] the settings object for the constructor call
     * @param settings.error the error enum to be reported
     * @param [settings.detailMessage] message containing details about the error
     */
    constructor(settings) {
        super({
            detailMessage: settings.detailMessage
                ? `${settings.detailMessage} (error: ${JSON.stringify(settings.error)})`
                : `${defaultMessage}${JSON.stringify(settings.error)}`
        });
        this.name = "";
        Object.defineProperty(this, "name", {
            enumerable: false,
            configurable: false,
            writable: true,
            value: "ApplicationException"
        });
        this._typeName = "joynr.exceptions.ApplicationException";
        this.error = settings.error;
        if (settings.error) {
            UtilInternal_1.checkProperty(settings.error.name, "String", "settings.error.name");
            UtilInternal_1.checkProperty(settings.error.value, ["String", "Number"], "settings.error.value");
        }
    }
}
ApplicationException._typeName = "joynr.exceptions.ApplicationException";
module.exports = ApplicationException;
