"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const UtilInternal_1 = require("../util/UtilInternal");
const JoynrRuntimeException_1 = __importDefault(require("./JoynrRuntimeException"));
class MethodInvocationException extends JoynrRuntimeException_1.default {
    /**
     * Constructor of MethodInvocationException object used for reporting
     * error conditions when invoking a method (e.g. method does not
     * exist or no method with matching signature found etc.) that should
     * be transmitted back to consumer side.
     *
     * @param [settings] the settings object for the constructor call
     * @param [settings.providerVersion] the version of the provider
     *            which could not handle the method invocation
     * @param [settings.detailMessage] message containing details about the error
     */
    constructor(settings) {
        super(settings);
        this.name = "";
        /**
         * Used for serialization.
         */
        this._typeName = "joynr.exceptions.MethodInvocationException";
        Object.defineProperty(this, "name", {
            enumerable: false,
            configurable: false,
            writable: true,
            value: "MethodInvocationException"
        });
        this.providerVersion = settings.providerVersion;
        if (settings) {
            UtilInternal_1.checkProperty(settings, "Object", "settings");
            UtilInternal_1.checkPropertyIfDefined(settings.providerVersion, "Version", "settings.providerVersion");
        }
    }
}
MethodInvocationException._typeName = "joynr.exceptions.MethodInvocationException";
module.exports = MethodInvocationException;
