"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const DiscoveryException_1 = __importDefault(require("./DiscoveryException"));
class NoCompatibleProviderFoundException extends DiscoveryException_1.default {
    /**
     * Constructor of NoCompatibleProviderFoundException object used for reporting
     * error conditions during discovery and arbitration when only providers
     * with incompatible versions are found. At least one such provider must
     * have been found, otherwise DiscoveryException will be used.
     *
     * @param [settings] the settings object for the constructor call
     * @param [settings.detailMessage] message containing details
     *            about the error
     * @param [settings.interfaceName] the name of the interface
     * @param [settings.discoveredVersions] list of discovered but incompatible provider versions
     */
    constructor(settings) {
        super(settings);
        this.name = "";
        /**
         * Used for serialization.
         */
        this._typeName = "joynr.exceptions.NoCompatibleProviderFoundException";
        Object.defineProperty(this, "name", {
            enumerable: false,
            configurable: false,
            writable: true,
            value: "NoCompatibleProviderFoundException"
        });
        this.discoveredVersions = settings.discoveredVersions;
        this.interfaceName = settings.interfaceName;
    }
}
NoCompatibleProviderFoundException._typeName = "joynr.exceptions.NoCompatibleProviderFoundException";
module.exports = NoCompatibleProviderFoundException;
