interface SmrfMessage {
    ttlMs: number;
    recipient: string;
    sender: string;
    isCompressed: boolean;
    creator: string;
    headers: Record<string, any>;
}
declare class JoynrMessage implements Partial<SmrfMessage> {
    ttlMs?: number;
    recipient?: string;
    sender?: string;
    isCompressed?: boolean;
    creator?: string;
    isLocalMessage?: boolean;
    isReceivedFromGlobal?: boolean;
    isTtlAbsolute?: boolean;
    encryptionCert: any;
    signingCert: any;
    signingKey: any;
    static readonly JOYNRMESSAGE_HEADER_TO_PARTICIPANT_ID: string;
    static readonly JOYNRMESSAGE_HEADER_CONTENT_TYPE: string;
    static readonly JOYNRMESSAGE_HEADER_REPLY_CHANNELID: string;
    static readonly JOYNRMESSAGE_HEADER_EFFORT: string;
    static readonly JOYNRMESSAGE_HEADER_CREATOR_USER_ID: string;
    static readonly JOYNRMESSAGE_TYPE_SUBSCRIPTION_STOP: string;
    static readonly JOYNRMESSAGE_TYPE_MULTICAST: string;
    static readonly JOYNRMESSAGE_TYPE_PUBLICATION: string;
    static readonly JOYNRMESSAGE_TYPE_SUBSCRIPTION_REPLY: string;
    static readonly JOYNRMESSAGE_TYPE_BROADCAST_SUBSCRIPTION_REQUEST: string;
    static readonly JOYNRMESSAGE_TYPE_MULTICAST_SUBSCRIPTION_REQUEST: string;
    static readonly JOYNRMESSAGE_TYPE_SUBSCRIPTION_REQUEST: string;
    static readonly JOYNRMESSAGE_TYPE_REPLY: string;
    static readonly JOYNRMESSAGE_TYPE_REQUEST: string;
    static readonly JOYNRMESSAGE_TYPE_ONE_WAY: string;
    headers: Record<string, any>;
    _typeName?: string;
    payload: any;
    signingCallback?: Function;
    /**
     * @param payload
     * @param type the message type as defined by JoynrMessage.JOYNRMESSAGE_TYPE_*
     * @param msgId
     */
    constructor({ payload, type, msgId }: {
        payload: string;
        type: string;
        msgId?: string;
    });
    static setSigningCallback(callback: Function): void;
    static parseMessage(settings: any): JoynrMessage;
    /**
     * @param customHeaders a map containing key/value pairs of headers to be set as custom
     *            headers. The keys will be added to the header field with the prefix
     *            MESSAGE_CUSTOM_HEADER_PREFIX
     * @returns joynrMessage instance for chainable calls
     */
    setCustomHeaders(customHeaders: Record<string, any>): JoynrMessage;
    /**
     * @returns customHeader object containing all headers that begin with the
     *          prefix MESSAGE_CUSTOM_HEADER_PREFIX
     */
    getCustomHeaders(): Record<string, any>;
    /**
     * @param key is one of the header keys defined in JoynrMessagingDefines
     * @param value of the header
     * @returns joynrMessage instance for chainable calls
     */
    setHeader(key: string, value: any): JoynrMessage;
    /**
     * @param key is one of the header keys defined in JoynrMessagingDefines
     * @returns value of header key
     */
    getHeader(key: string): any;
    get type(): string;
    set type(value: string);
    /**
     * @returns The participant id the message is to
     */
    get to(): string;
    /**
     * @param value The participant id the message is to
     */
    set to(value: string);
    /**
     * @returns The participant id the message is from
     */
    get from(): string;
    /**
     * @param value The participant id the message is from
     */
    set from(value: string);
    /**
     * @param value The expiry date of the message
     */
    set expiryDate(value: number);
    /**
     * @returns The expiry date of the message
     */
    get expiryDate(): number;
    /**
     * @param value The reply channel Id to return response messages to
     */
    set replyChannelId(value: string);
    /**
     * @returns The reply channel Id to return response messages to
     */
    get replyChannelId(): string;
    set msgId(value: string);
    get msgId(): string;
    set compress(value: boolean);
    get compress(): boolean;
    /**
     * @param value The effort to be expended while delivering the message
     */
    set effort(value: "NORMAL" | "BEST_EFFORT");
    /**
     * @returns The effort to be expended while delivering the message
     */
    get effort(): "NORMAL" | "BEST_EFFORT";
}
export = JoynrMessage;
