"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * #%L
 * %%
 * Copyright (C) 2019 BMW Car IT GmbH
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*eslint global-require: "off"*/
const JoynrMessage_1 = __importDefault(require("./JoynrMessage"));
const LoggingManager_1 = __importDefault(require("../system/LoggingManager"));
const log = LoggingManager_1.default.getLogger("joynr.messaging.MessageSerializer");
const smrf = __importStar(require("smrf"));
function serializeSmrfMessage(smrfMsg) {
    try {
        return smrf.serialize(smrfMsg);
    }
    catch (e) {
        throw new Error(`smrf.serialize: got exception ${e}`);
    }
}
function deserializeSmrfMessage(data) {
    try {
        return smrf.deserialize(data);
    }
    catch (e) {
        throw new Error(`smrf.deserialize: got exception ${e}`);
    }
}
function stringify(joynrMessage) {
    // @ts-ignore
    joynrMessage.body = joynrMessage.body || Buffer.from(joynrMessage.payload);
    return serializeSmrfMessage(joynrMessage);
}
exports.stringify = stringify;
function parse(data) {
    if (typeof data !== "object") {
        log.error("MessageSerializer received unsupported message.");
    }
    else {
        const smrfMsg = deserializeSmrfMessage(data);
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        const expiryDate = smrfMsg.isTtlAbsolute === true ? smrfMsg.ttlMs : smrfMsg.ttlMs + Date.now();
        // smrfMsg has two attributes we need to throw away -> create new Object
        const messageWithoutRest = {
            headers: smrfMsg.headers,
            sender: smrfMsg.sender,
            recipient: smrfMsg.recipient,
            ttlMs: expiryDate,
            // @ts-ignore
            payload: smrfMsg.body.toString()
        };
        return JoynrMessage_1.default.parseMessage(messageWithoutRest);
    }
}
exports.parse = parse;
