import * as MessagingQosEffort from "./MessagingQosEffort";
declare namespace MessagingQos {
    interface Settings {
        ttl: number;
        encrypt: boolean;
        compress: boolean;
        effort: MessagingQosEffort.NORMAL | MessagingQosEffort.BEST_EFFORT;
        customHeaders: Record<string, any>;
    }
}
declare class MessagingQos {
    /**
     * @name MessagingQos.DEFAULT_COMPRESS
     * @type Boolean
     * @default false
     * @static
     * @readonly
     */
    static DEFAULT_COMPRESS: boolean;
    /**
     * @name MessagingQos.DEFAULT_ENCRYPT
     * @type Boolean
     * @default false
     * @static
     * @readonly
     */
    static DEFAULT_ENCRYPT: boolean;
    /**
     * @name MessagingQos.DEFAULT_TTL
     * @type Number
     * @default 60000
     * @static
     * @readonly
     */
    static DEFAULT_TTL: number;
    compress: boolean;
    encrypt: boolean;
    effort: MessagingQosEffort.NORMAL | MessagingQosEffort.BEST_EFFORT;
    /**
     * custom message headers
     *
     * @name MessagingQos#customHeaders
     * @type Object
     */
    customHeaders?: Record<string, any>;
    /**
     * The time to live for messages in ms
     */
    ttl: number;
    /**
     * Constructor of MessagingQos object that is used in the generation of proxy objects
     *
     * @param [settings] the settings object for the constructor call
     * @param [settings.ttl] Roundtrip timeout for rpc requests, if missing default value is 60 seconds
     * @param [settings.encrypt] Specifies whether messages will be sent encrypted
     * @param [settings.compress] Specifies whether messages will be sent compressed
     * @param [settings.effort] effort to expend on ensuring message delivery
     */
    constructor(settings?: Partial<MessagingQos.Settings>);
    /**
     * @param key may contain ascii alphanumeric or hyphen.
     * @param value may contain alphanumeric, space, semi-colon, colon, comma, plus, ampersand,
     *  question mark, hyphen, dot, star, forward slash and back slash.
     */
    putCustomMessageHeader(key: string, value: string): void;
}
export = MessagingQos;
