"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const UtilInternal = __importStar(require("../util/UtilInternal"));
const LoggingManager_1 = __importDefault(require("../system/LoggingManager"));
const log = LoggingManager_1.default.getLogger("joynr/messaging/MessagingStubFactory");
class MessagingStubFactory {
    /**
     * @constructor
     *
     * @param settings
     * @param settings.messagingStubFactories a hash mapping addresses to the equivalent message sender
     * @param settings.messagingStubFactories.KEY the key of the map is the className of the address provided in createMessagingStub, the value is the concrete MessagingStubFactory
     * @param settings.messagingStubFactories.KEY.build the factory method of the
     */
    constructor(settings) {
        this.messagingStubFactories = settings.messagingStubFactories;
    }
    /**
     * @param address the address to create a messaging stub for
     */
    createMessagingStub(address) {
        const className = address._typeName;
        const factory = this.messagingStubFactories[className];
        if (UtilInternal.checkNullUndefined(factory)) {
            const errorMsg = `Could not find a MessagingStubFactory for "${className}" within messagingStubFactories [${Object.keys(this.messagingStubFactories).join(",")}]`;
            log.debug(errorMsg);
            throw new Error(errorMsg);
        }
        return factory.build(address);
    }
}
module.exports = MessagingStubFactory;
