"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
/*
 * #%L
 * %%
 * Copyright (C) 2019 BMW Car IT GmbH
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
const JoynrMessage_1 = __importDefault(require("../JoynrMessage"));
const Typing = __importStar(require("../../util/Typing"));
const UtilInternal = __importStar(require("../../util/UtilInternal"));
const JSONSerializer = __importStar(require("../../util/JSONSerializer"));
const LoggingManager_1 = __importDefault(require("../../system/LoggingManager"));
class BrowserMessagingSkeleton {
    /**
     * @constructor BrowserMessagingSkeleton
     *
     * @param settings
     * @param settings.webMessagingSkeleton a web messaging skeleton receiving web messages
     */
    constructor(settings) {
        this.log = LoggingManager_1.default.getLogger("joynr/messaging/browser/BrowserMessagingSkeleton");
        Typing.checkProperty(settings, "Object", "settings");
        Typing.checkProperty(settings.webMessagingSkeleton, Object, "settings.webMessagingSkeleton");
        this.receiverCallbacks = [];
        this.webMessagingSkeletonListener = this.webMessagingSkeletonListener.bind(this);
        settings.webMessagingSkeleton.registerListener(this.webMessagingSkeletonListener);
    }
    /**
     * Registers the listener function
     *
     * @param listener a listener function that should be added and should receive messages
     */
    registerListener(listener) {
        Typing.checkProperty(listener, "Function", "listener");
        this.receiverCallbacks.push(listener);
    }
    /**
     * Unregisters the listener function
     *
     * @param listener the listener function that should re removed and shouldn't receive messages any more
     */
    unregisterListener(listener) {
        Typing.checkProperty(listener, "Function", "listener");
        UtilInternal.removeElementFromArray(this.receiverCallbacks, listener);
    }
    webMessagingSkeletonListener(message) {
        if (message !== undefined) {
            const joynrMessage = new JoynrMessage_1.default(message);
            UtilInternal.fire(this.receiverCallbacks, joynrMessage);
        }
        else {
            this.log.warn(`message with content "${JSONSerializer.stringify(message)}" could not be processed`);
        }
    }
}
module.exports = BrowserMessagingSkeleton;
