"use strict";
class MqttMessagingSkeleton {
    /**
     * @constructor MqttMessagingSkeleton
     * @param settings
     * @param settings.client the mqtt client to be used to transmit messages
     * @param settings.messageRouter the message router
     * @param settings.address own address of joynr client
     */
    constructor(settings) {
        this.multicastSubscriptionCount = {};
        this.client = settings.client;
        this.client.onmessage = function (_topic, message) {
            message.isReceivedFromGlobal = true;
            settings.messageRouter.route(message);
        };
        this.client.subscribe(`${settings.address.topic}/#`);
    }
    translateWildcard(multicastId) {
        if (multicastId.match(/[\w\W]*\/[*]$/)) {
            return multicastId.replace(/\/\*/g, "/#");
        }
        return multicastId;
    }
    registerMulticastSubscription(multicastId) {
        if (this.multicastSubscriptionCount[multicastId] === undefined) {
            this.multicastSubscriptionCount[multicastId] = 0;
        }
        this.client.subscribe(this.translateWildcard(multicastId));
        this.multicastSubscriptionCount[multicastId] = this.multicastSubscriptionCount[multicastId] + 1;
    }
    unregisterMulticastSubscription(multicastId) {
        let subscribersCount = this.multicastSubscriptionCount[multicastId];
        if (subscribersCount !== undefined) {
            subscribersCount--;
            if (subscribersCount === 0) {
                this.client.unsubscribe(this.translateWildcard(multicastId));
                delete this.multicastSubscriptionCount[multicastId];
            }
            else {
                this.multicastSubscriptionCount[multicastId] = subscribersCount;
            }
        }
    }
    shutdown() {
        this.client.close();
    }
}
module.exports = MqttMessagingSkeleton;
