/// <reference types="node" />
import JoynrMessage = require("../JoynrMessage");
declare class MessageQueue {
    static DEFAULT_MAX_QUEUE_SIZE_IN_KBYTES: number;
    cleanupInterval: NodeJS.Timer;
    currentQueueSize: number;
    private participantQueues;
    maxQueueSizeInKBytes: number;
    /**
     * MessageQueue caches incoming messages, and cached messages can be retrieved in case the destination participant becomes visible
     *
     * @constructor
     *
     * @param settings the settings object holding dependencies
     * @param settings.maxQueueSizeInKBytes the maximum buffer size that shall be allocated by the message queue
     *
     * @classdesc The <code>MessageQueue</code> is a joynr internal data structure. The Message Queue caches incoming messages, which cannot be shipped
     * to the correct participant. Once a participant with the matching participantId is registered, the incoming message is forwarded to him
     */
    constructor(settings: {
        maxQueueSizeInKBytes?: number;
    });
    putMessage(message: JoynrMessage): void;
    /**
     * gets the queue messages for the participant
     *
     * @param participantId
     */
    getAndRemoveMessages(participantId: string): JoynrMessage[];
    /**
     * Shutdown the message queue
     */
    shutdown(): void;
}
export = MessageQueue;
