"use strict";
/* eslint-disable @typescript-eslint/no-non-null-assertion */
/*
 * #%L
 * %%
 * Copyright (C) 2020 BMW Car IT GmbH
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
/*eslint no-use-before-define: "off"*/
const LoggingManager_1 = __importDefault(require("../../system/LoggingManager"));
const log = LoggingManager_1.default.getLogger("joynr.messaging.socket.MagicCookieUtil");
class MagicCookieUtil {
    static getPayloadBuff(data) {
        return Buffer.from(data.subarray(this.OFFSET_BEGIN_PAYLOAD, data.length));
    }
    static getPayloadLength(data) {
        const infoLengthAsString = data.readUInt32BE(MagicCookieUtil.OFFSET_BEGIN_PAYLOAD_LENGTH);
        return parseInt(infoLengthAsString);
    }
    static getMagicCookieBuff(data) {
        return Buffer.from(data.subarray(this.OFFSET_BEGIN_COOKIE, this.OFFSET_END_COOKIE));
    }
    static writeMagicCookies(serializedJoynrMessageBuff, magicCookie) {
        const payloadLengthBuff = Buffer.alloc(4, 0); // 4 bytes, initialized with 0
        payloadLengthBuff.writeUInt32BE(serializedJoynrMessageBuff.length, 0);
        const magicCookieBuff = Buffer.from(magicCookie);
        const arrayOfBuffers = [magicCookieBuff, payloadLengthBuff, serializedJoynrMessageBuff];
        return Buffer.concat(arrayOfBuffers);
    }
    static checkCookie(internBuff) {
        const magicCookie = this.getMagicCookieBuff(internBuff).toString();
        log.debug(`received this MagicCookie: ${magicCookie}`);
        if (magicCookie !== this.MESSAGE_COOKIE) {
            const errorMsg = `Invalid cookies. Cookie type must be ${this.MESSAGE_COOKIE}, received : ${magicCookie}, connection closed`;
            log.fatal(errorMsg);
            return false;
        }
        return true;
    }
}
// range: [BEGIN, END[
MagicCookieUtil.OFFSET_BEGIN_COOKIE = 0;
MagicCookieUtil.OFFSET_END_COOKIE = 4;
MagicCookieUtil.OFFSET_BEGIN_PAYLOAD_LENGTH = 4;
MagicCookieUtil.OFFSET_BEGIN_PAYLOAD = 8;
/** Magic cookie precedes every init-frame */
MagicCookieUtil.INIT_COOKIE = `MJI1`;
/** Magic cookie precedes every message-frame */
MagicCookieUtil.MESSAGE_COOKIE = `MJM1`;
/** placeholder for magic cookie is 4 bytes + placeholder for payload length is 4 bytes */
MagicCookieUtil.MAGIC_COOKIE_AND_PAYLOAD_LENGTH = 8;
module.exports = MagicCookieUtil;
