import JoynrMessage from "../JoynrMessage";
import JoynrRuntimeException from "../../exceptions/JoynrRuntimeException";
interface UdsLibJoynrProvisioning {
    socketPath: string;
    clientId: string;
    connectSleepTimeMs: number;
    onMessageCallback: Function;
    onFatalRuntimeError: (error: JoynrRuntimeException) => void;
}
declare class UdsClient {
    /**
     util.promisify creates the callback which will be called by socket.write once the message was sent.
     When the callback is called with an error it will reject the promise, otherwise resolve it.
     The arrow function is there to assure that socket.write is called with socket as its this context.
     */
    private readonly promisifyWriteToSocket;
    private reconnectTimer;
    private connected;
    private closed;
    private queuedMessages;
    private readonly onMessageCallback;
    private readonly onFatalRuntimeError;
    private readonly connectSleepTimeMs;
    private socket;
    private readonly socketPath;
    private readonly clientId?;
    private internBuff;
    private readonly serializedUdsClientAddress;
    /**
     * @constructor
     * @param parameters
     * @param parameters.socketPath: path of uds socket to communicate to the server through it
     * @param parameters.clientId: client id
     * @param parameters.connectSleepTimeMs: interval to try to connect to the server when it is unavailable
     * @param parameters.onMessageCallback: callback to be called when a complete message arrives
     * @param parameters.onFatalRuntimeError: callback to be called when a fatal error in UdsClient happens that
     * prevents further communication via UDS in this runtime
     */
    constructor(parameters: UdsLibJoynrProvisioning);
    private readonly establishConnection;
    private readonly onConnect;
    private readonly onClose;
    private readonly onEnd;
    private readonly onError;
    private readonly onReceivedMessage;
    private processReceivedBuffer;
    private processExtractedMessage;
    get numberOfQueuedMessages(): number;
    private sendQueuedMessages;
    private serializeJoynrMessage;
    /**
     * @param joynrMessage the joynr message to transmit
     */
    send(joynrMessage: JoynrMessage): Promise<void>;
    private sendInternal;
    private writeToSocket;
    /**
     * Normally the UdsClient.send api automatically resolves the Promise
     * when it's called. But this doesn't mean that the data was actually
     * written out. This method is a helper for a graceful shutdown which delays
     * the resolving of the UdsClient.send Promise till the data is
     * written out, to make sure that unsubscribe messages are successfully sent.
     */
    enableShutdownMode(): void;
    /**
     * Ends connection to the socket
     */
    shutdown(callback?: Function): void;
}
export = UdsClient;
