"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
/*
 * #%L
 * %%
 * Copyright (C) 2019 BMW Car IT GmbH
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
const Typing = __importStar(require("../../util/Typing"));
class WebMessagingAddress {
    /**
     * @constructor WebMessagingAddress
     * @param settings the settings object for this constructor call
     * @param settings.window the default target window, the messages should be sent to
     * @param settings.origin the default origin, the messages should be sent to
     */
    constructor(settings) {
        Typing.checkProperty(settings, "Object", "settings");
        Typing.checkProperty(settings.window, "Object", "settings.window");
        Typing.checkProperty(settings.origin, "String", "settings.origin");
        this.settings = settings;
    }
    /**
     * @returns the windows that should be addressed
     */
    getWindow() {
        return this.settings.window;
    }
    /**
     * @returns the origin of the window that should be addressed
     * @see WebMessagingAddress#getWindow
     */
    getOrigin() {
        return this.settings.origin;
    }
}
module.exports = WebMessagingAddress;
