/// <reference types="node" />
import * as WebSocketAddress from "../../../generated/joynr/system/RoutingTypes/WebSocketAddress";
import * as WebSocketClientAddress from "../../../generated/joynr/system/RoutingTypes/WebSocketClientAddress";
import JoynrMessage = require("../JoynrMessage");
interface SharedWebSocketSettings {
    localAddress: WebSocketClientAddress;
    remoteAddress: WebSocketAddress;
    provisioning: {
        reconnectSleepTimeMs?: number;
    };
    keychain: any;
}
declare class SharedWebSocket {
    static EVENT_CODE_SHUTDOWN: number;
    /**
       util.promisify creates the callback which will be called by ws once the message was sent.
       When the callback is called with an error it will reject the promise, otherwise resolve it.
       The arrow function is there to assure that websocket.send is called with websocket as its this context.
     */
    private webSocketSendAsync;
    private sendConfig;
    private reconnectTimer;
    private closed;
    private queuedMessages;
    private onmessageCallback;
    private remoteUrl;
    private localAddress;
    private reconnectSleepTimeMs;
    private websocket;
    private keychain;
    /**
     * @constructor
     * @param settings
     * @param settings.localAddress address used by the websocket server to contact this
     *            client. This address is used in in the init phase on the websocket, and
     *            then registered with the message router on the remote side
     * @param settings.remoteAddress to which messages are sent on the websocket server.
     * @param settings.provisioning
     * @param settings.provisioning.reconnectSleepTimeMs
     * @param settings.keychain
     */
    constructor(settings: SharedWebSocketSettings);
    get onmessage(): Function;
    set onmessage(newCallback: Function);
    get numberOfQueuedMessages(): number;
    private sendQueuedMessages;
    private resetConnection;
    private onError;
    private onClose;
    private onOpen;
    sendInternal(marshaledMessage: Buffer): Promise<void>;
    sendMessage(joynrMessage: JoynrMessage): Promise<void>;
    /**
     * @param joynrMessage the joynr message to transmit
     */
    send(joynrMessage: JoynrMessage): Promise<void>;
    /**
     * Normally the SharedWebsocket.send api automatically resolves the Promise
     * when it's called. But this doesn't mean that the data was actually
     * written out. This method is a helper for a graceful shutdown which delays
     * the resolving of the SharedWebSocket.send Promise till the data is
     * written out, to make sure that unsubscribe messages are successfully sent.
     */
    enableShutdownMode(): void;
    close(): void;
}
export = SharedWebSocket;
