"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
/*
 * #%L
 * %%
 * Copyright (C) 2019 BMW Car IT GmbH
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
const JoynrMessage_1 = __importDefault(require("../JoynrMessage"));
const Typing = __importStar(require("../../util/Typing"));
const LoggingManager_1 = __importDefault(require("../../system/LoggingManager"));
const log = LoggingManager_1.default.getLogger("joynr.messaging.websocket.WebSocketMessagingSkeleton");
class WebSocketMessagingSkeleton {
    /**
     * @constructor WebSocketMessagingSkeleton
     * @param settings
     * @param settings.sharedWebSocket
     * @param settings.mainTransport
     */
    constructor(settings) {
        this.sharedWebSocket = settings.sharedWebSocket;
        settings.sharedWebSocket.onmessage = (joynrMessage) => {
            log.debug(`<<< INCOMING <<< message with ID ${joynrMessage.msgId}`);
            if (this.listener !== undefined) {
                if (joynrMessage.type === JoynrMessage_1.default.JOYNRMESSAGE_TYPE_MULTICAST && settings.mainTransport) {
                    joynrMessage.isReceivedFromGlobal = true;
                }
                this.listener(joynrMessage);
            }
        };
    }
    /**
     * Registers the listener function
     *
     * @param listener a listener function that should be added and should receive messages
     */
    registerListener(listener) {
        Typing.checkProperty(listener, "Function", "listenerToAdd");
        this.listener = listener;
    }
    /**
     * Unregisters the listener function
     *
     * @param _listener the listener function that should re removed and shouldn't receive
     *            messages any more
     */
    unregisterListener(_listener) {
        this.listener = undefined;
    }
    /* */
    shutdown() {
        this.sharedWebSocket.close();
    }
}
module.exports = WebSocketMessagingSkeleton;
