import BroadcastOutputParameters from "./BroadcastOutputParameters";
interface ProviderEventSettings {
    eventName: string;
    selective?: boolean;
    outputParameterProperties: Record<string, any>;
    filterSettings: Record<string, any>;
}
declare class ProviderEvent {
    selective?: boolean;
    private settings;
    private filters;
    private callbacks;
    /**
     * Constructor of ProviderEvent object that is used in the generation of provider objects
     *
     * @constructor
     *
     * @param settings the settings for this provider event
     * @param settings.eventName the name of the event
     * @param settings.selective true if the broadcast is selective
     * @param settings.outputParameterProperties the output parameter names and types
     * @param settings.filterSettings the filter settings
     */
    constructor(settings: ProviderEventSettings);
    /**
     * @param filterParametersInput an object containing a map filterParameters
     */
    checkFilterParameters(filterParametersInput: Record<string, any>): {
        caughtErrors: string[];
    };
    createBroadcastOutputParameters(): BroadcastOutputParameters;
    /**
     * if this event is fired the applications should call this function with the new
     * output parameters which causes the publication containing the values to be
     * sent to all subscribers.
     *
     * @param broadcastOutputParameters the broadcast output parameters
     * @param [partitions] - the partitions to be used for multicasts
     * @throws {Error} if partitions contains invalid characters
     */
    fire(broadcastOutputParameters: BroadcastOutputParameters, partitions?: string[]): void;
    /**
     * Registers an Observer for value changes
     *
     * @param observer the callback function with the signature "function(value){..}"
     * @see ProviderEvent#unregisterObserver
     */
    registerObserver(observer: Function): void;
    /**
     * Unregisters an Observer for value changes
     *
     * @param observer the callback function with the signature "function(value){..}"
     * @see ProviderEvent#registerObserver
     */
    unregisterObserver(observer: Function): void;
    /**
     * Registers a filter
     *
     * @param filter the callback object with a filter function that executes the filtering
     * @see ProviderEvent#deleteBroadcastFilter
     */
    addBroadcastFilter(filter: {
        filter: Function;
    }): void;
    /**
     * Unregisters an Observer for value changes
     *
     * @param filter the to be removed callback object with a filter function that executes the filtering
     * @see ProviderEvent#addBroadcastFilter
     */
    deleteBroadcastFilter(filter: {
        filter: Function;
    }): void;
}
export = ProviderEvent;
