interface OperationSignature {
    inputParameter: {
        name: string;
        type: string;
    }[];
    error: {
        type: string;
    };
    outputParameter: {
        name: string;
        type: string;
    }[];
}
declare class ProviderOperation {
    private operationSignatures;
    operationName: string;
    private privateOperationFunc;
    /**
     * Constructor of ProviderAttribute object that is used in the generation of provider objects
     * @param [implementation] the operation function
     * @param operationName the name of the operation
     * @param operationSignatures an object with the argument name as key and an object
     *            as value defining the type
     * @param operationSignatures.array an object with the argument name as key and an
     *            object as value defining the type
     * @param operationSignatures.array.PARAMETERNAME an object describing the single
     *            parameter
     * @param operationSignatures.array.PARAMETERNAME.type the type of the parameter
     */
    constructor(implementation: Function, operationName: string, operationSignatures: OperationSignature[]);
    /**
     * Registers the operation function
     *
     * @param operationFunc registers the operation function
     */
    registerOperation(operationFunc: Function): void;
    /**
     * Calls the operation function.
     *
     * @param operationArguments the operation arguments as an array
     * @param operationArguments the operation argument value, e.g. 1
     * @param operationArgumentTypes the operation argument types as an array
     * @param operationArgumentTypes the operation argument type in String form e.g. "Integer"
     *
     * @returns the return type of the called operation function
     */
    callOperation(operationArguments: any, operationArgumentTypes: string[]): Promise<any>;
    /**
     * Check if the registered operation is defined.
     * @returns if the registered operation is defined.
     */
    checkOperation(): boolean;
}
export = ProviderOperation;
