"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
/*
 * #%L
 * %%
 * Copyright (C) 2019 BMW Car IT GmbH
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
const Typing = __importStar(require("../util/Typing"));
function makeSetterFunction(obj, parameterName) {
    return function (arg) {
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        obj.filterParameters[parameterName] = arg;
        return obj;
    };
}
class BroadcastFilterParameters {
    /**
     * Constructor of BroadcastFilterParameters object used for subscriptions in generated proxy objects
     *
     * @param [filterParameterProperties] the filterParameters object for the constructor call
     *
     * @returns {BroadcastFilterParameters} a BroadcastFilterParameters Object for subscriptions on broadcasts
     */
    constructor(filterParameterProperties) {
        this._typeName = "joynr.BroadcastFilterParameters";
        this.filterParameters = {};
        Typing.checkPropertyIfDefined(filterParameterProperties, "Object", "filterParameters");
        if (filterParameterProperties === undefined) {
            this.filterParameters = null;
        }
        else {
            for (const parameterName in filterParameterProperties) {
                if (Object.prototype.hasOwnProperty.call(filterParameterProperties, parameterName)) {
                    const funcName = `set${parameterName.charAt(0).toUpperCase()}${parameterName.substring(1)}`;
                    //filter[funcName] = makeSetterFunction(filter, parameterName);
                    Object.defineProperty(this, funcName, {
                        configurable: false,
                        writable: false,
                        enumerable: false,
                        value: makeSetterFunction(this, parameterName)
                    });
                }
            }
        }
    }
}
module.exports = BroadcastFilterParameters;
