import * as DiscoveryEntryWithMetaInfo from "../../generated/joynr/types/DiscoveryEntryWithMetaInfo";
import DiscoveryScope from "../../generated/joynr/types/DiscoveryScope";
declare namespace DiscoveryQos {
    interface Settings {
        discoveryTimeoutMs: number;
        discoveryRetryDelayMs: number;
        arbitrationStrategy: (discoveryEntries: DiscoveryEntryWithMetaInfo[]) => DiscoveryEntryWithMetaInfo[];
        cacheMaxAgeMs: number;
        discoveryScope: DiscoveryScope;
        providerMustSupportOnChange: boolean;
        additionalParameters: Record<string, any>;
    }
}
declare class DiscoveryQos {
    additionalParameters: Record<string, any>;
    providerMustSupportOnChange: boolean;
    discoveryScope: DiscoveryScope;
    cacheMaxAgeMs: number;
    arbitrationStrategy: (discoveryEntries: DiscoveryEntryWithMetaInfo[]) => DiscoveryEntryWithMetaInfo[];
    discoveryRetryDelayMs: number;
    discoveryTimeoutMs: number;
    /**
     * Constructor of DiscoveryQos object that is used in the generation of proxy objects
     *
     * @param [settings] the settings object for the constructor call
     * @param [settings.discoveryTimeoutMs] for rpc calls to wait for arbitration to finish.
     * @param [settings.discoveryRetryDelayMs] the minimum delay between two arbitration retries
     * @param [settings.arbitrationStrategy] Strategy for choosing the appropriate provider from the list returned by the capabilities directory with the function signature "function(CapabilityInfos[])" that returns an array of CapabilityInfos
     * @param [settings.cacheMaxAgeMs] Maximum age of entries in the localCapabilitiesDirectory. If this value filters out all entries of the local capabilities directory a lookup in the global capabilitiesDirectory will take place.
     * @param [settings.discoveryScope] default  is LOCAL_AND_GLOBAL
     * @param [settings.providerMustSupportOnChange] default false
     * @param [settings.additionalParameters] a map holding additional parameters in the form of key value pairs in the javascript object, e.g.: {"myKey": "myValue", "myKey2": 5} @returns {DiscoveryQos} a discovery Qos Object
     */
    constructor(settings?: Partial<DiscoveryQos.Settings>);
    static setDefaultSettings(settings: Partial<DiscoveryQos.Settings>): void;
}
export = DiscoveryQos;
