"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const ArbitrationStrategyCollection = __importStar(require("../../joynr/types/ArbitrationStrategyCollection"));
const DiscoveryScope_1 = __importDefault(require("../../generated/joynr/types/DiscoveryScope"));
const UtilInternal = __importStar(require("../util/UtilInternal"));
let defaultSettings = {
    discoveryTimeoutMs: 10 * 60 * 1000,
    discoveryRetryDelayMs: 10 * 1000,
    arbitrationStrategy: ArbitrationStrategyCollection.LastSeen,
    cacheMaxAgeMs: 0,
    discoveryScope: DiscoveryScope_1.default.LOCAL_THEN_GLOBAL,
    providerMustSupportOnChange: false,
    additionalParameters: {}
};
class DiscoveryQos {
    /**
     * Constructor of DiscoveryQos object that is used in the generation of proxy objects
     *
     * @param [settings] the settings object for the constructor call
     * @param [settings.discoveryTimeoutMs] for rpc calls to wait for arbitration to finish.
     * @param [settings.discoveryRetryDelayMs] the minimum delay between two arbitration retries
     * @param [settings.arbitrationStrategy] Strategy for choosing the appropriate provider from the list returned by the capabilities directory with the function signature "function(CapabilityInfos[])" that returns an array of CapabilityInfos
     * @param [settings.cacheMaxAgeMs] Maximum age of entries in the localCapabilitiesDirectory. If this value filters out all entries of the local capabilities directory a lookup in the global capabilitiesDirectory will take place.
     * @param [settings.discoveryScope] default  is LOCAL_AND_GLOBAL
     * @param [settings.providerMustSupportOnChange] default false
     * @param [settings.additionalParameters] a map holding additional parameters in the form of key value pairs in the javascript object, e.g.: {"myKey": "myValue", "myKey2": 5} @returns {DiscoveryQos} a discovery Qos Object
     */
    constructor(settings) {
        const augmentedSettings = UtilInternal.extend({}, defaultSettings, settings);
        this.discoveryTimeoutMs = augmentedSettings.discoveryTimeoutMs;
        this.discoveryRetryDelayMs = augmentedSettings.discoveryRetryDelayMs;
        this.arbitrationStrategy = augmentedSettings.arbitrationStrategy;
        this.cacheMaxAgeMs = augmentedSettings.cacheMaxAgeMs;
        this.discoveryScope = augmentedSettings.discoveryScope;
        this.providerMustSupportOnChange = augmentedSettings.providerMustSupportOnChange;
        this.additionalParameters = augmentedSettings.additionalParameters;
    }
    static setDefaultSettings(settings) {
        defaultSettings = UtilInternal.extend({}, defaultSettings, settings);
    }
}
module.exports = DiscoveryQos;
