import SubscriptionQos from "./SubscriptionQos";
declare class MulticastSubscriptionQos extends SubscriptionQos {
    /**
     * @classdesc
     * Class representing the quality of service settings for non-selective
     * broadcasts.<br/>
     * This class stores quality of service settings used for subscriptions to
     * <b>non-selective broadcasts</b> in generated proxy objects. Notifications
     * will be sent  whenever the provider fires a broadcast. The subscription
     * will automatically expire after the expiry date is reached.<br/>
     *
     * @summary
     * Constructor of MulticastSubscriptionQos object used for subscriptions
     * to <b>non-selective broadcasts</b> in generated proxy objects.
     *
     * @param [settings] the settings object for the constructor call
     * @param [settings.expiryDateMs] how long is the subscription valid
     * @param [settings.validityMs] The validity of the subscription relative to the current time.
     *
     * @see {@link SubscriptionQos} for more information on <b>expiryDateMs</b> and <b>validityMs</b>
     */
    constructor(settings?: {
        expiryDateMs?: number;
        validityMs?: number;
    });
}
export = MulticastSubscriptionQos;
