"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
/*
 * #%L
 * %%
 * Copyright (C) 2019 BMW Car IT GmbH
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
const SubscriptionQos_1 = __importDefault(require("./SubscriptionQos"));
class MulticastSubscriptionQos extends SubscriptionQos_1.default {
    /**
     * @classdesc
     * Class representing the quality of service settings for non-selective
     * broadcasts.<br/>
     * This class stores quality of service settings used for subscriptions to
     * <b>non-selective broadcasts</b> in generated proxy objects. Notifications
     * will be sent  whenever the provider fires a broadcast. The subscription
     * will automatically expire after the expiry date is reached.<br/>
     *
     * @summary
     * Constructor of MulticastSubscriptionQos object used for subscriptions
     * to <b>non-selective broadcasts</b> in generated proxy objects.
     *
     * @param [settings] the settings object for the constructor call
     * @param [settings.expiryDateMs] how long is the subscription valid
     * @param [settings.validityMs] The validity of the subscription relative to the current time.
     *
     * @see {@link SubscriptionQos} for more information on <b>expiryDateMs</b> and <b>validityMs</b>
     */
    constructor(settings) {
        super(settings);
        this._typeName = "joynr.MulticastSubscriptionQos";
    }
}
module.exports = MulticastSubscriptionQos;
