import OnChangeSubscriptionQos from "./OnChangeSubscriptionQos";
declare class OnChangeWithKeepAliveSubscriptionQos extends OnChangeSubscriptionQos {
    /**
     * Default value for [maxIntervalMs]{@link OnChangeWithKeepAliveSubscriptionQos#maxIntervalMs}.
     * See [constructor description]{@link OnChangeWithKeepAliveSubscriptionQos}.
     */
    static readonly DEFAULT_MAX_INTERVAL_MS = 60000;
    /**
     * Maximum value for [maxIntervalMs]{@link OnChangeWithKeepAliveSubscriptionQos#maxIntervalMs}.
     * See [constructor description]{@link OnChangeWithKeepAliveSubscriptionQos}.
     */
    static readonly MAX_MAX_INTERVAL_MS = 2592000000;
    /**
     * Minimal value for [maxIntervalMs]{@link OnChangeWithKeepAliveSubscriptionQos#maxIntervalMs}.
     * See [constructor description]{@link OnChangeWithKeepAliveSubscriptionQos}.
     */
    static readonly MIN_MAX_INTERVAL_MS = 50;
    /**
     * Maximum value for [alertAfterIntervalMs]{@link OnChangeWithKeepAliveSubscriptionQos#alertAfterIntervalMs}.
     * See [constructor description]{@link OnChangeWithKeepAliveSubscriptionQos}.
     */
    static readonly MAX_ALERT_AFTER_INTERVAL_MS = 2592000000;
    /**
     * Default value for [alertAfterIntervalMs]{@link OnChangeWithKeepAliveSubscriptionQos#alertAfterIntervalMs}.
     * See [constructor description]{@link OnChangeWithKeepAliveSubscriptionQos}.
     */
    static readonly NO_ALERT_AFTER_INTERVAL = 0;
    /**
     * Default value for [alertAfterIntervalMs]{@link OnChangeWithKeepAliveSubscriptionQos#alertAfterIntervalMs}.
     * See [constructor description]{@link OnChangeWithKeepAliveSubscriptionQos}.
     */
    static readonly DEFAULT_ALERT_AFTER_INTERVAL_MS = 0;
    alertAfterIntervalMs: number;
    maxIntervalMs: number;
    /**
     * @classdesc
     * Class representing the quality of service settings for subscriptions
     * based on changes and time periods
     * <br/>
     * This class stores quality of service settings used for subscriptions to
     * <b>attributes</b> in generated proxy objects. Using it for subscriptions
     * to events is theoretically possible because of inheritance but makes
     * no sense (in this case the additional members will be ignored).
     * <br/>
     * Notifications will be sent if the subscribed value has changed or a time
     * interval without notifications has expired. The subscription will
     * automatically expire after the expiry date is reached. If no publications
     * were received for alertAfterIntervalMs, publicationMissed will be called.
     * <br/>
     * minIntervalMs can be used to prevent too many messages being sent.
     *
     * @summary
     * Constructor of OnChangeWithKeepAliveSubscriptionQos object used
     * for subscriptions to <b>attributes</b> in generated proxy objects
     *
     * @param [settings] the settings object for the constructor call
     * @param [settings.minIntervalMs] defines how often an update may be sent
     * @param [settings.maxIntervalMs=OnChangeWithKeepAliveSubscriptionQos.DEFAULT_MAX_INTERVAL_MS]
     *            defines how long to wait before sending an update even if the value did not change<br/>
     *            The provider will send publications every maximum interval in
     *            milliseconds, even if the value didn't change. It will send
     *            notifications more often if on-change notifications are enabled,
     *            the value changes more often, and the minimum interval QoS does
     *            not prevent it. The maximum interval can thus be seen as a sort
     *            of heart beat or keep alive interval, if no other publication
     *            has been sent within that time.<br/>
     *            <br/>
     *            <b>Minimum, Maximum and Default Values</b>
     *            <ul>
     *              <li>minimum value: {@link OnChangeWithKeepAliveSubscriptionQos#minIntervalMs} or
     *                                 {@link OnChangeWithKeepAliveSubscriptionQos.MIN_MAX_INTERVAL_MS}</li>
     *              <li>maximum value: {@link OnChangeWithKeepAliveSubscriptionQos.MAX_MAX_INTERVAL_MS}</li>
     *              <li>default value: {@link OnChangeWithKeepAliveSubscriptionQos.DEFAULT_MAX_INTERVAL_MS}</li>
     *            </ul>
     * @param [settings.expiryDateMs] how long is the subscription valid
     * @param [settings.validityMs] The validity of the subscription relative to the current time.
     * @param [settings.alertAfterIntervalMs=OnChangeWithKeepAliveSubscriptionQos.DEFAULT_ALERT_AFTER_INTERVAL_MS]
     *            defines how long to wait for an update before publicationMissed is called<br/>
     *            <br/>
     *            <b>Minimum, Maximum and Default Values:</b>
     *            <ul>
     *              <li>minimum value: {@link OnChangeWithKeepAliveSubscriptionQos#maxIntervalMs}</li>
     *              <li>maximum value: {@link OnChangeWithKeepAliveSubscriptionQos.MAX_ALERT_AFTER_INTERVAL_MS}</li>
     *              <li>default value: {@link OnChangeWithKeepAliveSubscriptionQos.DEFAULT_ALERT_AFTER_INTERVAL_MS}</li>
     *            </ul>
     * @param [settings.publicationTtlMs] time to live for publication messages
     *
     * @see {@link OnChangeSubscriptionQos} for more information on <b>minIntervalMs</b>
     * @see {@link SubscriptionQos} for more information on <b>expiryDateMs</b>
     * and <b>publicationTtlMs</b>
     */
    constructor(settings?: {
        expiryDateMs?: number;
        validityMs?: number;
        publicationTtlMs?: number;
        minIntervalMs?: number;
        maxIntervalMs?: number;
        alertAfterIntervalMs?: number;
    });
    /**
     * The function clearAlertAfterInterval resets the alter after interval to
     * the value OnChangeWithKeepAliveSubscriptionQos.NO_ALERT_AFTER_INTERVAL
     */
    clearAlertAfterInterval(): void;
}
export = OnChangeWithKeepAliveSubscriptionQos;
