import SubscriptionQos from "./SubscriptionQos";
declare class PeriodicSubscriptionQos extends SubscriptionQos {
    /**
     * Default value for [alertAfterIntervalMs]{@link PeriodicSubscriptionQos#alertAfterIntervalMs}.
     * See [constructor description]{@link PeriodicSubscriptionQos}.
     */
    static readonly NO_ALERT_AFTER_INTERVAL = 0;
    /**
     * Default value for [alertAfterIntervalMs]{@link PeriodicSubscriptionQos#alertAfterIntervalMs}.
     * See [constructor description]{@link PeriodicSubscriptionQos}.
     */
    static readonly DEFAULT_ALERT_AFTER_INTERVAL_MS = 0;
    /**
     * Maximum value for [alertAfterIntervalMs]{@link PeriodicSubscriptionQos#alertAfterIntervalMs}.
     * See [constructor description]{@link PeriodicSubscriptionQos}.
     */
    static readonly MAX_ALERT_AFTER_INTERVAL_MS = 2592000000;
    /**
     * Default value for [periodMs]{@link PeriodicSubscriptionQos#periodMs}.
     * See [constructor description]{@link PeriodicSubscriptionQos}.
     */
    static readonly DEFAULT_PERIOD_MS = 60000;
    /**
     * Maximum value for [periodMs]{@link PeriodicSubscriptionQos#periodMs}.
     * See [constructor description]{@link PeriodicSubscriptionQos}.
     */
    static readonly MAX_PERIOD_MS = 2592000000;
    /**
     * Minimal value for [periodMs]{@link PeriodicSubscriptionQos#periodMs}.
     * See [constructor description]{@link PeriodicSubscriptionQos}.
     */
    static readonly MIN_PERIOD_MS = 50;
    static MIN_PERIOD: number;
    alertAfterIntervalMs: number;
    periodMs: number;
    /**
     * @classdesc
     * Class representing the quality of service settings for subscriptions based
     * on time periods.<br/>
     * This class stores quality of service settings used for subscriptions to
     * <b>attributes</b> in generated proxy objects. Notifications will only be
     * sent if the period has expired. The subscription will automatically expire
     * after the expiry date is reached. If no publications were received for
     * alertAfterIntervalMs, publicationMissed will be called.
     *
     * @summary
     * Constructor of PeriodicSubscriptionQos object used for subscriptions
     * to <b>attributes</b> in generated proxy objects.
     *
     * @param [settings] the settings object for the constructor call
     * @param [settings.periodMs=PeriodicSubscriptionQos.DEFAULT_PERIOD_MS] defines
     *            how often an update may be sent even if the value did not change
     *            (independently from value changes).<br/>
     *            <br/>
     *            <b>Minimum, Maximum and Default Values:</b>
     *            <ul>
     *              <li>minimum value: {@link PeriodicSubscriptionQos.MIN_PERIOD_MS}</li>
     *              <li>maximum value: {@link PeriodicSubscriptionQos.MAX_PERIOD_MS}</li>
     *              <li>default value: {@link PeriodicSubscriptionQos.DEFAULT_PERIOD_MS}</li>
     *            </ul>
     * @param [settings.expiryDateMs] how long is the subscription valid
     * @param [settings.validityMs] The validity of the subscription relative to the current time.
     * @param [settings.alertAfterIntervalMs=PeriodicSubscriptionQos.DEFAULT_ALERT_AFTER_INTERVAL_MS] defines how long to wait for an
     *            update before publicationMissed is called.<br/>
     *            <br/>
     *            <b>Minimum, Maximum and Default Values:</b>
     *            <ul>
     *              <li>minimum value: {@link PeriodicSubscriptionQos#period}</li>
     *              <li>maximum value: {@link PeriodicSubscriptionQos.MAX_ALERT_AFTER_INTERVAL_MS}</li>
     *              <li>default value: {@link PeriodicSubscriptionQos.DEFAULT_ALERT_AFTER_INTERVAL_MS}</li>
     *            </ul>
     * @param [settings.publicationTtlMs] Time to live for publication messages
     *
     * @see {@link SubscriptionQos} for more information on <b>expiryDateMs</b>
     * and <b>publicationTtlMs</b>
     */
    constructor(settings?: {
        expiryDateMs?: number;
        validityMs?: number;
        publicationTtlMs?: number;
        periodMs?: number;
        alertAfterIntervalMs?: number;
    });
    /**
     * The function clearAlertAfterInterval resets the alter after interval to
     * the value PeriodicSubscriptionQos.NO_ALERT_AFTER_INTERVAL
     */
    clearAlertAfterInterval(): void;
}
export = PeriodicSubscriptionQos;
