import * as DiscoveryEntryWithMetaInfo from "../../generated/joynr/types/DiscoveryEntryWithMetaInfo";
import * as Request from "../dispatching/types/Request";
import MessagingQos from "../messaging/MessagingQos";
import RequestReplyManager = require("../dispatching/RequestReplyManager");
import SubscriptionManager = require("../dispatching/subscription/SubscriptionManager");
import DiscoveryQos = require("./DiscoveryQos");
import SubscriptionQos = require("./SubscriptionQos");
declare type ProxyAttributeConstructor<T = ProxyAttribute> = new (...args: any[]) => T;
export interface SubscribeSettings<T> {
    subscriptionQos: SubscriptionQos;
    onReceive: (value: T) => void;
    onError?: (e: Error) => void;
    onSubscribed?: (participantId: string) => void;
    subscriptionId?: string;
}
declare class ProxyAttribute {
    /** protected property, needs to be public for tsc -d */
    attributeType: string;
    /** protected property, needs to be public for tsc -d */
    attributeName: string;
    settings: {
        dependencies: {
            requestReplyManager: RequestReplyManager;
            subscriptionManager: SubscriptionManager;
        };
        discoveryQos: DiscoveryQos;
        messagingQos: MessagingQos;
    };
    /** protected property, needs to be public for tsc -d */
    parent: {
        proxyParticipantId: string;
        providerDiscoveryEntry: DiscoveryEntryWithMetaInfo;
        messagingQos?: MessagingQos;
    };
    /**
     * Constructor of ProxyAttribute object that is used in the generation of proxy objects
     *
     * @param parent - the proxy object that contains this attribute
     * @param parent.proxyParticipantId - participantId of the proxy itself
     * @param parent.providerDiscoveryEntry.participantId - participantId of the provider being addressed
     * @param settings - the settings object for this function call
     * @param settings.dependencies - the dependencies object for this function call
     * @param settings.dependencies.requestReplyManager
     * @param settings.dependencies.subscriptionManager
     * @param settings.discoveryQos - the Quality of Service parameters for arbitration
     * @param settings.messagingQos - the Quality of Service parameters for messaging
     * @param attributeName - the name of the attribute
     * @param attributeType - the type of the attribute
     */
    constructor(parent: {
        proxyParticipantId: string;
        providerDiscoveryEntry: DiscoveryEntryWithMetaInfo;
        settings: {
            dependencies: {
                requestReplyManager: RequestReplyManager;
                subscriptionManager: SubscriptionManager;
            };
            discoveryQos: DiscoveryQos;
            messagingQos: MessagingQos;
        };
    }, attributeName: string, attributeType: string);
    /**
     * protected property, but public due to tsc -d
     *
     * @param request
     * @param requestSettings
     * @param requestSettings.messagingQos
     * @returns an A+ promise
     */
    executeRequest(request: Request.Request, requestSettings: {
        messagingQos?: MessagingQos;
    }): Promise<any>;
}
declare const ProxyReadAttributeImpl: {
    new (...args: any[]): {
        /**
         * Getter for attribute
         *
         * @param [settings] the settings object for this function call
         * @returns returns an A+ promise object
         */
        get(settings?: {
            messagingQos?: MessagingQos | undefined;
        } | undefined): Promise<unknown>;
        /** protected property, needs to be public for tsc -d */
        attributeType: string;
        /** protected property, needs to be public for tsc -d */
        attributeName: string;
        settings: {
            dependencies: {
                requestReplyManager: RequestReplyManager;
                subscriptionManager: SubscriptionManager;
            };
            discoveryQos: DiscoveryQos;
            messagingQos: MessagingQos;
        };
        /** protected property, needs to be public for tsc -d */
        parent: {
            proxyParticipantId: string;
            providerDiscoveryEntry: DiscoveryEntryWithMetaInfo;
            messagingQos?: MessagingQos | undefined;
        };
        /**
         * protected property, but public due to tsc -d
         *
         * @param request
         * @param requestSettings
         * @param requestSettings.messagingQos
         * @returns an A+ promise
         */
        executeRequest(request: Request.Request, requestSettings: {
            messagingQos?: MessagingQos | undefined;
        }): Promise<any>;
    };
} & ProxyAttributeConstructor<ProxyAttribute>;
export declare class ProxyReadAttribute<T> extends ProxyReadAttributeImpl {
    get: (settings?: {
        messagingQos?: MessagingQos;
    }) => Promise<T>;
}
declare const ProxyReadWriteAttributeImpl: {
    new (...args: any[]): {
        /**
         * Setter for attribute
         *
         * @param settings - the settings object for this function call
         * @param settings.value - the attribute value to set
         * @returns returns an A+ promise
         */
        set(settings: {
            value: unknown;
            messagingQos?: MessagingQos | undefined;
        }): Promise<void>;
        /** protected property, needs to be public for tsc -d */
        attributeType: string;
        /** protected property, needs to be public for tsc -d */
        attributeName: string;
        settings: {
            dependencies: {
                requestReplyManager: RequestReplyManager;
                subscriptionManager: SubscriptionManager;
            };
            discoveryQos: DiscoveryQos;
            messagingQos: MessagingQos;
        };
        /** protected property, needs to be public for tsc -d */
        parent: {
            proxyParticipantId: string;
            providerDiscoveryEntry: DiscoveryEntryWithMetaInfo;
            messagingQos?: MessagingQos | undefined;
        };
        /**
         * protected property, but public due to tsc -d
         *
         * @param request
         * @param requestSettings
         * @param requestSettings.messagingQos
         * @returns an A+ promise
         */
        executeRequest(request: Request.Request, requestSettings: {
            messagingQos?: MessagingQos | undefined;
        }): Promise<any>;
    };
} & ProxyAttributeConstructor<ProxyAttribute>;
export declare class ProxyReadWriteAttribute<T> extends ProxyReadWriteAttributeImpl {
    get: (settings?: {
        messagingQos?: MessagingQos;
    }) => Promise<T>;
    set: (settings: {
        value: T;
        messagingQos?: MessagingQos;
    }) => Promise<void>;
}
declare const ProxyReadWriteNotifyAttributeImpl: {
    new (...args: any[]): {
        /**
         * Subscription to isOn attribute
         *
         * @param settings the settings object for this function call
         * @param settings.subscriptionQos - the subscription quality of service object
         * @param settings.onReceive this function is called if the attribute has
         *            been published successfully, method signature:
         *            "void onReceive({?}value)"
         * @param settings.onError - this function is called if a publication of the attribute value was
         *          missed, method signature: "void onError({Error} error)"
         * @param settings.onSubscribed - the callback to inform once the subscription request has been
         *          delivered successfully
         * @param [settings.subscriptionId] - optional subscriptionId to be used for the new subscription
         * @returns returns an A+ promise object
         */
        subscribe(settings: SubscribeSettings<unknown>): Promise<string>;
        /**
         * Unsubscribe from the attribute
         *
         * @param settings - the settings object for this function call
         * @param settings.subscriptionId - the subscription id retrieved from the subscribe function
         * @returns returns an A+ promise object
         *
         * @see ProxyAttribute#subscribe
         */
        unsubscribe(settings: {
            subscriptionId: string;
            messagingQos?: MessagingQos | undefined;
        }): Promise<void>;
        /** protected property, needs to be public for tsc -d */
        attributeType: string;
        /** protected property, needs to be public for tsc -d */
        attributeName: string;
        settings: {
            dependencies: {
                requestReplyManager: RequestReplyManager;
                subscriptionManager: SubscriptionManager;
            };
            discoveryQos: DiscoveryQos;
            messagingQos: MessagingQos;
        };
        /** protected property, needs to be public for tsc -d */
        parent: {
            proxyParticipantId: string;
            providerDiscoveryEntry: DiscoveryEntryWithMetaInfo;
            messagingQos?: MessagingQos | undefined;
        };
        /**
         * protected property, but public due to tsc -d
         *
         * @param request
         * @param requestSettings
         * @param requestSettings.messagingQos
         * @returns an A+ promise
         */
        executeRequest(request: Request.Request, requestSettings: {
            messagingQos?: MessagingQos | undefined;
        }): Promise<any>;
    };
} & ProxyAttributeConstructor<ProxyAttribute>;
export declare class ProxyReadWriteNotifyAttribute<T> extends ProxyReadWriteNotifyAttributeImpl {
    get: (settings?: {
        messagingQos?: MessagingQos;
    }) => Promise<T>;
    set: (settings: {
        value: T;
        messagingQos?: MessagingQos;
    }) => Promise<void>;
    subscribe: (settings: SubscribeSettings<T>) => Promise<any>;
    unsubscribe: (settings: {
        subscriptionId: string;
        messagingQos?: MessagingQos;
    }) => Promise<void>;
}
declare const ProxyReadNotifyAttributeImpl: {
    new (...args: any[]): {
        /**
         * Subscription to isOn attribute
         *
         * @param settings the settings object for this function call
         * @param settings.subscriptionQos - the subscription quality of service object
         * @param settings.onReceive this function is called if the attribute has
         *            been published successfully, method signature:
         *            "void onReceive({?}value)"
         * @param settings.onError - this function is called if a publication of the attribute value was
         *          missed, method signature: "void onError({Error} error)"
         * @param settings.onSubscribed - the callback to inform once the subscription request has been
         *          delivered successfully
         * @param [settings.subscriptionId] - optional subscriptionId to be used for the new subscription
         * @returns returns an A+ promise object
         */
        subscribe(settings: SubscribeSettings<unknown>): Promise<string>;
        /**
         * Unsubscribe from the attribute
         *
         * @param settings - the settings object for this function call
         * @param settings.subscriptionId - the subscription id retrieved from the subscribe function
         * @returns returns an A+ promise object
         *
         * @see ProxyAttribute#subscribe
         */
        unsubscribe(settings: {
            subscriptionId: string;
            messagingQos?: MessagingQos | undefined;
        }): Promise<void>;
        /** protected property, needs to be public for tsc -d */
        attributeType: string;
        /** protected property, needs to be public for tsc -d */
        attributeName: string;
        settings: {
            dependencies: {
                requestReplyManager: RequestReplyManager;
                subscriptionManager: SubscriptionManager;
            };
            discoveryQos: DiscoveryQos;
            messagingQos: MessagingQos;
        };
        /** protected property, needs to be public for tsc -d */
        parent: {
            proxyParticipantId: string;
            providerDiscoveryEntry: DiscoveryEntryWithMetaInfo;
            messagingQos?: MessagingQos | undefined;
        };
        /**
         * protected property, but public due to tsc -d
         *
         * @param request
         * @param requestSettings
         * @param requestSettings.messagingQos
         * @returns an A+ promise
         */
        executeRequest(request: Request.Request, requestSettings: {
            messagingQos?: MessagingQos | undefined;
        }): Promise<any>;
    };
} & ProxyAttributeConstructor<ProxyAttribute>;
export declare class ProxyReadNotifyAttribute<T> extends ProxyReadNotifyAttributeImpl {
    get: (settings?: {
        messagingQos?: MessagingQos;
    }) => Promise<T>;
    subscribe: (settings: SubscribeSettings<T>) => Promise<any>;
    unsubscribe: (settings: {
        subscriptionId: string;
        messagingQos?: MessagingQos;
    }) => Promise<void>;
}
export {};
