import MessagingQos from "../messaging/MessagingQos";
import RequestReplyManager from "../dispatching/RequestReplyManager";
declare class ProxyOperation {
    private readonly operationSignatures;
    private readonly operationName;
    messagingQos: MessagingQos;
    private requestReplyManager;
    /**
     * The parent proxy object
     */
    protected parent: any;
    /**
     * Constructor of ProxyOperation object that is used in the generation of proxy objects
     *
     * @param parent is the proxy object that contains this attribute
     * @param parent.proxyParticipantId - participantId of the proxy itself
     * @param parent.providerDiscoveryEntry.participantId - participantId of the provider being addressed
     * @param parent.settings.dependencies.requestReplyManager
     * @param operationName the name of the operation
     * @param operationSignatures an array of possible signatures for this operation
     * @param operationSignatures.array.inputParameter an array of supported arguments for
     *            one specific signature
     * @param operationSignatures.array.inputParameter.name the name of the input parameter
     * @param operationSignatures.array.inputParameter.type the type of the input parameter
     * @param operationSignatures.array.outputParameter an array of output parameters for
     *            one specific signature
     * @param operationSignatures.array.outputParameter.name the name of the output parameter
     * @param operationSignatures.array.outputParameter.type the type of the output parameter
     */
    constructor(parent: {
        messagingQos: MessagingQos;
        settings: {
            dependencies: {
                requestReplyManager: RequestReplyManager;
            };
        };
        proxyParticipantId: string;
        providerDiscoveryEntry: {
            participantId: string;
        };
    }, operationName: string, operationSignatures: {
        inputParameter: {
            name: string;
            type: string;
        }[];
        outputParameter?: {
            name: string;
            type: string;
        }[];
        fireAndForget?: boolean;
    }[]);
    /**
     * Generic operation implementation
     *
     * @param operationArguments: this object contains all parameters
     * @param operationArguments.OPERATIONARGUMENTNAME: CUSTOM DOC FROM IDL GOES
     *            HERE, contains the argument value
     *
     * @returns Promise
     */
    operationFunction(operationArguments: Record<string, any>): Promise<any>;
    /**
     * Operation Function builder
     *
     * @returns returns the operation function that can be assigned to a
     *            member of the proxy
     */
    buildFunction(): Function;
}
export = ProxyOperation;
