declare class SubscriptionQos {
    /**
     * Default value for [publicationTtlMs]{@link SubscriptionQos#publicationTtlMs} in
     * milliseconds (10 secs). See [constructor description]{@link SubscriptionQos}.
     */
    static readonly DEFAULT_PUBLICATION_TTL_MS = 10000;
    static DEFAULT_PUBLICATION_TTL: number;
    static readonly NO_EXPIRY_DATE_TTL: number;
    /**
     * Default value for [expiryDateMs]{@link SubscriptionQos#expiryDateMs} in milliseconds
     * (no expiry date). See [constructor description]{@link SubscriptionQos}.
     */
    static readonly NO_EXPIRY_DATE = 0;
    /**
     * Minimal value for [expiryDateMs]{@link SubscriptionQos#expiryDateMs} in milliseconds
     * (0 secs). See [constructor description]{@link SubscriptionQos}.
     */
    static readonly MIN_EXPIRY_MS = 0;
    /**
     * Maximum value for [publicationTtlMs]{@link SubscriptionQos#publicationTtlMs}.
     * See [constructor description]{@link SubscriptionQos}.
     *
     * @default 2 592 000 000 (30 days)
     */
    static readonly MAX_PUBLICATION_TTL_MS = 2592000000;
    /**
     * Minimal value for [publicationTtlMs]{@link SubscriptionQos#publicationTtlMs}.
     * See [constructor description]{@link SubscriptionQos}.
     */
    static readonly MIN_PUBLICATION_TTL_MS = 100;
    /**
     * Used for serialization.
     */
    _typeName: string;
    /**
     * See [constructor description]{@link SubscriptionQos}.
     */
    expiryDateMs: number;
    /**
     * See [constructor description]{@link SubscriptionQos}.
     */
    publicationTtlMs: number;
    /**
     * @classdesc
     * Base class representing the subscription quality of service settings.
     * This class stores quality of service settings used for subscriptions to
     * <b>attributes and broadcasts</b> in generated proxy objects.<br/>
     * Subclasses are {@link PeriodicSubscriptionQos},
     * {@link OnChangeSubscriptionQos}, and
     * {@link OnChangeWithKeepAliveSubscriptionQos}.<br/>
     * The provider will send notifications until the expiry date is reached. The
     * subscription will automatically expire after the expiry date is reached.
     *
     * @summary
     * Constructor of SubscriptionQos object used for subscriptions to
     * <b>attributes and events</b> in generated proxy objects.
     *
     * @param [settings] the settings object for the constructor call
     * @param [settings.expiryDateMs=SubscriptionQos.NO_EXPIRY_DATE] The expiry date is the
     *            end date of the subscription. This value is provided in milliseconds
     *            (since 1970-01-01T00:00:00.000).<br/>
     *            <br/>
     *            <b>Minimum and Default Values:</b>
     *            <ul>
     *              <li>minimum value: {@link SubscriptionQos.MIN_EXPIRY_MS}</li>
     *              <li>default value: {@link SubscriptionQos.NO_EXPIRY_DATE}</li>
     *            </ul>
     * @param [settings.validityMs] The validity of the subscription relative to the current time.
     *            <br/>
     *            <b>Special Values:</b>
     *            <ul>
     *              <li>minimum value: 0</li>
     *            </ul>
     * @param [settings.publicationTtlMs=SubscriptionQos.DEFAULT_PUBLICATION_TTL_MS]
     *            Time to live for publication messages.<br/>
     *            <br/>
     *            If a notification message can not be delivered within its time
     *            to live, it will be deleted from the system. This value is
     *            provided in milliseconds.<br/>
     *            <br/>
     *            <b>Minimum, Maximum and Default Values:</b>
     *            <ul>
     *              <li>minimum value: {@link SubscriptionQos.MIN_PUBLICATION_TTL_MS}</li>
     *              <li>maximum value: {@link SubscriptionQos.MAX_PUBLICATION_TTL_MS}</li>
     *              <li>default value: {@link SubscriptionQos.DEFAULT_PUBLICATION_TTL_MS}</li>
     *            </ul>
     */
    constructor(settings?: {
        expiryDateMs?: number;
        validityMs?: number;
        publicationTtlMs?: number;
    });
    /**
     * The function clearExpiryDate resets the expiry date to the default value SubscriptionQos.NO_EXPIRY_DATE
     *
     */
    clearExpiryDate(): void;
}
export = SubscriptionQos;
