import { InProcessProvisioning, ShutdownSettings } from "./interface/Provisioning";
import JoynrRuntime from "./JoynrRuntime";
import JoynrRuntimeException from "../exceptions/JoynrRuntimeException";
/**
 * The InProcessRuntime is the version of the libjoynr-js runtime that hosts its own
 * cluster controller
 *
 * @name InProcessRuntime
 * @constructor
 *
 * @param provisioning
 */
declare class InProcessRuntime extends JoynrRuntime<InProcessProvisioning> {
    private freshnessIntervalId;
    constructor(onFatalRuntimeError: (error: JoynrRuntimeException) => void);
    /**
     * Starts up the libjoynr instance
     *
     * @returns an A+ promise object, reporting when libjoynr startup is
     *          then({InProcessRuntime}, {Error})-ed
     * @throws {Error} if libjoynr is not in SHUTDOWN state
     */
    start(provisioning: InProcessProvisioning): Promise<void>;
    /**
     * Shuts down libjoynr
     *
     * @throws {Error} if libjoynr is not in the STARTED state
     */
    shutdown(settings: ShutdownSettings): Promise<void>;
}
export = InProcessRuntime;
