"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
/*
 * #%L
 * %%
 * Copyright (C) 2019 BMW Car IT GmbH
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*eslint promise/catch-or-return: "off"*/
const GlobalDiscoveryEntry_1 = __importDefault(require("../../generated/joynr/types/GlobalDiscoveryEntry"));
const CapabilityDiscovery_1 = __importDefault(require("../capabilities/discovery/CapabilityDiscovery"));
const CapabilitiesStore_1 = __importDefault(require("../capabilities/CapabilitiesStore"));
const ChannelAddress_1 = __importDefault(require("../../generated/joynr/system/RoutingTypes/ChannelAddress"));
const MqttMessagingStubFactory_1 = __importDefault(require("../messaging/mqtt/MqttMessagingStubFactory"));
const MqttMessagingSkeleton_1 = __importDefault(require("../messaging/mqtt/MqttMessagingSkeleton"));
const MqttAddress_1 = __importDefault(require("../../generated/joynr/system/RoutingTypes/MqttAddress"));
const SharedMqttClient_1 = __importDefault(require("../messaging/mqtt/SharedMqttClient"));
const MqttMulticastAddressCalculator_1 = __importDefault(require("../messaging/mqtt/MqttMulticastAddressCalculator"));
const MessagingStubFactory_1 = __importDefault(require("../messaging/MessagingStubFactory"));
const InProcessMessagingStubFactory_1 = __importDefault(require("../messaging/inprocess/InProcessMessagingStubFactory"));
const InProcessAddress_1 = __importDefault(require("../messaging/inprocess/InProcessAddress"));
const UtilInternal = __importStar(require("../util/UtilInternal"));
const CapabilitiesUtil = __importStar(require("../util/CapabilitiesUtil"));
const LoggingManager_1 = __importDefault(require("../system/LoggingManager"));
const nanoid_1 = require("nanoid");
const defaultLibjoynrSettings_1 = __importDefault(require("./settings/defaultLibjoynrSettings"));
const defaultClusterControllerSettings_1 = __importDefault(require("./settings/defaultClusterControllerSettings"));
const Typing = __importStar(require("../util/Typing"));
const LongTimer_1 = __importDefault(require("../util/LongTimer"));
const JoynrStates = {
    SHUTDOWN: "shut down",
    STARTING: "starting",
    STARTED: "started",
    SHUTTINGDOWN: "shutting down"
};
const JoynrRuntime_1 = __importDefault(require("./JoynrRuntime"));
const InProcessMessagingSkeleton_1 = __importDefault(require("../messaging/inprocess/InProcessMessagingSkeleton"));
const InProcessMessagingStub_1 = __importDefault(require("../messaging/inprocess/InProcessMessagingStub"));
const log = LoggingManager_1.default.getLogger("joynr.start.InProcessRuntime");
/**
 * The InProcessRuntime is the version of the libjoynr-js runtime that hosts its own
 * cluster controller
 *
 * @name InProcessRuntime
 * @constructor
 *
 * @param provisioning
 */
class InProcessRuntime extends JoynrRuntime_1.default {
    constructor(onFatalRuntimeError) {
        super(onFatalRuntimeError);
        this.freshnessIntervalId = null;
    }
    /**
     * Starts up the libjoynr instance
     *
     * @returns an A+ promise object, reporting when libjoynr startup is
     *          then({InProcessRuntime}, {Error})-ed
     * @throws {Error} if libjoynr is not in SHUTDOWN state
     */
    async start(provisioning) {
        super.start(provisioning);
        if (UtilInternal.checkNullUndefined(provisioning.bounceProxyUrl)) {
            throw new Error("bounce proxy URL not set in provisioning.bounceProxyUrl");
        }
        if (UtilInternal.checkNullUndefined(provisioning.bounceProxyBaseUrl)) {
            throw new Error("bounce proxy base URL not set in provisioning.bounceProxyBaseUrl");
        }
        if (UtilInternal.checkNullUndefined(provisioning.brokerUri)) {
            throw new Error("broker URI not set in provisioning.brokerUri");
        }
        const initialRoutingTable = {};
        await this.initializePersistency(provisioning);
        const channelId = provisioning.channelId ||
            (this.persistency && this.persistency.getItem("joynr.channels.channelId.1")) ||
            `chjs_${nanoid_1.nanoid()}`;
        if (this.persistency)
            this.persistency.setItem("joynr.channels.channelId.1", channelId);
        let untypedCapabilities = provisioning.capabilities || [];
        const clusterControllerSettings = defaultClusterControllerSettings_1.default({
            bounceProxyBaseUrl: provisioning.bounceProxyBaseUrl,
            brokerUri: provisioning.brokerUri
        });
        const defaultClusterControllerCapabilities = clusterControllerSettings.capabilities || [];
        untypedCapabilities = untypedCapabilities.concat(defaultClusterControllerCapabilities);
        this.typeRegistry.addType(ChannelAddress_1.default);
        this.typeRegistry.addType(MqttAddress_1.default);
        const typedCapabilities = [];
        for (let i = 0; i < untypedCapabilities.length; i++) {
            const capability = new GlobalDiscoveryEntry_1.default(untypedCapabilities[i]);
            if (!capability.address) {
                throw new Error(`provisioned capability is missing address: ${JSON.stringify(capability)}`);
            }
            initialRoutingTable[capability.participantId] = Typing.augmentTypes(JSON.parse(capability.address));
            typedCapabilities.push(capability);
        }
        const globalClusterControllerAddress = new MqttAddress_1.default({
            brokerUri: "joynrdefaultgbid",
            topic: channelId
        });
        const serializedGlobalClusterControllerAddress = JSON.stringify(globalClusterControllerAddress);
        const mqttClusterControllerAddress = new MqttAddress_1.default({
            brokerUri: provisioning.brokerUri,
            topic: channelId
        });
        const mqttClient = new SharedMqttClient_1.default({
            address: mqttClusterControllerAddress,
            provisioning: provisioning.mqtt || {}
        });
        const messagingStubFactories = {};
        messagingStubFactories[InProcessAddress_1.default._typeName] = new InProcessMessagingStubFactory_1.default();
        //messagingStubFactories[ChannelAddress._typeName] = channelMessagingStubFactory;
        messagingStubFactories[MqttAddress_1.default._typeName] = new MqttMessagingStubFactory_1.default({
            client: mqttClient
        });
        const messagingStubFactory = new MessagingStubFactory_1.default({
            messagingStubFactories
        });
        const messageRouterSettings = {
            initialRoutingTable,
            typeRegistry: this.typeRegistry,
            messagingStubFactory,
            multicastAddressCalculator: new MqttMulticastAddressCalculator_1.default({
                globalAddress: globalClusterControllerAddress
            })
        };
        const localCapabilitiesStore = new CapabilitiesStore_1.default(CapabilitiesUtil.toDiscoveryEntries(defaultLibjoynrSettings_1.default.capabilities || []));
        const globalCapabilitiesCache = new CapabilitiesStore_1.default(typedCapabilities);
        const capabilityDiscoveryDomain = "io.joynr";
        const capabilityDiscovery = new CapabilityDiscovery_1.default(localCapabilitiesStore, globalCapabilitiesCache, capabilityDiscoveryDomain, provisioning.gbids || clusterControllerSettings.gbids);
        super.createMessageRouter(provisioning, messageRouterSettings);
        const externalMessagingSkeleton = new InProcessMessagingSkeleton_1.default();
        const externalMessagingStub = new InProcessMessagingStub_1.default(externalMessagingSkeleton);
        externalMessagingSkeleton.registerListener(this.messageRouter.route);
        super.initializeComponents(provisioning, capabilityDiscovery, externalMessagingStub);
        const mqttMessagingSkeleton = new MqttMessagingSkeleton_1.default({
            address: globalClusterControllerAddress,
            client: mqttClient,
            messageRouter: this.messageRouter
        });
        this.multicastSkeletons[MqttAddress_1.default._typeName] = mqttMessagingSkeleton;
        this.messageRouter.setReplyToAddress(serializedGlobalClusterControllerAddress);
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        capabilityDiscovery.setDependencies(this.messageRouter, this.proxyBuilder);
        mqttClient.onConnected().then(() => {
            // TODO remove workaround when multiple backend support is implemented in JS
            const globalClusterControllerAddressWithGbid = new MqttAddress_1.default({
                brokerUri: "joynrdefaultgbid",
                topic: globalClusterControllerAddress.topic
            });
            capabilityDiscovery.globalAddressReady(globalClusterControllerAddressWithGbid);
        });
        const period = provisioning.capabilitiesFreshnessUpdateIntervalMs || 3600000; // default: 1 hour
        this.freshnessIntervalId = LongTimer_1.default.setInterval(() => {
            capabilityDiscovery.touch(channelId, period).catch((error) => {
                log.error(`error sending freshness update: ${error}`);
            });
        }, period);
        if (provisioning.logging) {
            LoggingManager_1.default.configure(provisioning.logging);
        }
        this.joynrState = JoynrStates.STARTED;
        log.debug("joynr initialized");
    }
    /**
     * Shuts down libjoynr
     *
     * @throws {Error} if libjoynr is not in the STARTED state
     */
    shutdown(settings) {
        LongTimer_1.default.clearInterval(this.freshnessIntervalId);
        return super.shutdown(settings);
    }
}
module.exports = InProcessRuntime;
