interface TypeConstructor {
    new (...args: any[]): any;
    _typeName: string;
}
declare class TypeRegistry {
    private registryPromise;
    private enumRegistry;
    private registry;
    /**
     * The <code>TypeRegistry</code> contains a mapping of type names (which are sent on the wire
     * through joynr) to the corresponding
     * JavaScript type constructor.
     *
     * This class is used during deserialization, ie mapping a received request/response to the
     * corresponding JavaScript call with the
     * correct parameters.
     *
     * @constructor
     */
    constructor();
    /**
     * Adds a typeName to constructor entry in the type registry.
     *
     * @param typeConstructor - the corresponding JavaScript constructor for this type.
     * @returns typeRegistry for chained calls.
     */
    addType(typeConstructor: TypeConstructor): TypeRegistry;
    /**
     * Detects if asked joynr type is an enumeration type
     *
     * @param joynrTypeName - the joynr type name that is sent/received on the wire.
     * @returns true if the asked joynr type is an enumeration type
     */
    isEnumType(joynrTypeName: string): boolean;
    /**
     * Retrieves the constructor for a given type.
     *
     * @param joynrTypeName - the joynr type name that is sent/received on the wire.
     * @returns the constructor function for the specified type name
     */
    getConstructor(joynrTypeName: string): any;
    /**
     * Shutdown the type registry
     */
    shutdown(): void;
}
export = TypeRegistry;
