import JoynrRuntime from "./JoynrRuntime";
import { ShutdownSettings, UdsLibJoynrProvisioning } from "./interface/Provisioning";
import JoynrRuntimeException from "../exceptions/JoynrRuntimeException";
/**
 * The UdsLibJoynrRuntime is the version of the libjoynr-js runtime that communicates with
 * a cluster controller via a unix domain socket (UDS). The cluster controller is the UDS Server, and the
 * libjoynr connects to it with a single socket for all communication.
 *
 * @name UdsLibJoynrRuntime
 * @constructor
 */
declare class UdsLibJoynrRuntime extends JoynrRuntime<UdsLibJoynrProvisioning> {
    private udsClient;
    private messageReplyToAddressCalculator;
    constructor(onFatalRuntimeError: (error: JoynrRuntimeException) => void);
    /**
     * Starts up the libjoynr instance
     *
     * @param {UdsLibJoynrProvisioning} provisioning
     * @returns an A+ promise object, reporting when libjoynr startup is
     *          completed or has failed
     * @throws {Error} if libjoynr is not in SHUTDOWN state
     */
    start(provisioning: UdsLibJoynrProvisioning): Promise<void>;
    /**
     *  Sends subscriptionStop messages for all active subscriptions.
     *
     *  @param timeout {number} optional timeout defaulting to 0 = no timeout
     *  @returns - resolved after all SubscriptionStop messages are sent.
     *  - rejected in case of any issues or timeout occurs.
     */
    terminateAllSubscriptions(timeout?: number): Promise<any>;
    /**
     * Shuts down libjoynr
     * @param settings.clearSubscriptionsTimeoutMs {number} time in ms till clearSubscriptionsPromise will be rejected
     *  if it's not resolved yet
     * @param settings.clearSubscriptionsEnabled {boolean} clear all subscriptions before shutting down.
     *  Set this to false in process.exit handler as this is not synchronous.
     *
     * @returns - resolved after successful shutdown
     * - rejected in case of any issues
     */
    shutdown(settings?: ShutdownSettings): Promise<any>;
}
export = UdsLibJoynrRuntime;
