import { ShutdownSettings, WebSocketLibjoynrProvisioning } from "./interface/Provisioning";
import JoynrRuntime from "./JoynrRuntime";
import JoynrRuntimeException from "../exceptions/JoynrRuntimeException";
/**
 * The WebSocketLibjoynrRuntime is the version of the libjoynr-js runtime that communicates with
 * a cluster controller via a WebSocket. The cluster controller is the WebSocket Server, and the
 * libjoynr connects to it with a single websocket for all communication.
 *
 * @name WebSocketLibjoynrRuntime
 * @constructor
 */
declare class WebSocketLibjoynrRuntime extends JoynrRuntime<WebSocketLibjoynrProvisioning> {
    private sharedWebSocket;
    private webSocketMessagingSkeleton;
    private bufferedOwnerId;
    constructor(onFatalRuntimeError: (error: JoynrRuntimeException) => void);
    private signingCallback;
    /**
     * Starts up the libjoynr instance
     *
     * @param {WebSocketLibjoynrProvisioning} provisioning
     * @returns an A+ promise object, reporting when libjoynr startup is
     *          completed or has failed
     * @throws {Error} if libjoynr is not in SHUTDOWN state
     */
    start(provisioning: WebSocketLibjoynrProvisioning): Promise<void>;
    /**
     *  Sends subscriptionStop messages for all active subscriptions.
     *
     *  @param timeout {number} optional timeout defaulting to 0 = no timeout
     *  @returns - resolved after all SubscriptionStop messages are sent.
     *  - rejected in case of any issues or timeout occurs.
     */
    terminateAllSubscriptions(timeout?: number): Promise<any>;
    /**
     * Shuts down libjoynr
     * @param settings.clearSubscriptionsTimeoutMs {number} time in ms till clearSubscriptionsPromise will be rejected
     *  if it's not resolved yet
     * @param settings.clearSubscriptionsEnabled {boolean} clear all subscriptions before shutting down.
     *  Set this to false in process.exit handler as this is not synchronous.
     *
     * @returns - resolved after successful shutdown
     * - rejected in case of any issues
     */
    shutdown(settings?: ShutdownSettings): Promise<any>;
}
export = WebSocketLibjoynrRuntime;
