"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
/*
 * #%L
 * %%
 * Copyright (C) 2019 BMW Car IT GmbH
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
const WebSocketProtocol = __importStar(require("../../generated/joynr/system/RoutingTypes/WebSocketProtocol"));
const SharedWebSocket_1 = __importDefault(require("../messaging/websocket/SharedWebSocket"));
const WebSocketMessagingSkeleton_1 = __importDefault(require("../messaging/websocket/WebSocketMessagingSkeleton"));
const WebSocketMessagingStubFactory_1 = __importDefault(require("../messaging/websocket/WebSocketMessagingStubFactory"));
const WebSocketMulticastAddressCalculator_1 = __importDefault(require("../messaging/websocket/WebSocketMulticastAddressCalculator"));
const MessagingStubFactory_1 = __importDefault(require("../messaging/MessagingStubFactory"));
const WebSocketAddress_1 = __importDefault(require("../../generated/joynr/system/RoutingTypes/WebSocketAddress"));
const WebSocketClientAddress_1 = __importDefault(require("../../generated/joynr/system/RoutingTypes/WebSocketClientAddress"));
const InProcessMessagingStubFactory_1 = __importDefault(require("../messaging/inprocess/InProcessMessagingStubFactory"));
const InProcessAddress_1 = __importDefault(require("../messaging/inprocess/InProcessAddress"));
const MessagingQos_1 = __importDefault(require("../messaging/MessagingQos"));
const DiscoveryQos_1 = __importDefault(require("../proxy/DiscoveryQos"));
const DiscoveryProxy_1 = __importDefault(require("../../generated/joynr/system/DiscoveryProxy"));
const RoutingProxy_1 = __importDefault(require("../../generated/joynr/system/RoutingProxy"));
const DiscoveryScope_1 = __importDefault(require("../../generated/joynr/types/DiscoveryScope"));
const DiscoveryEntryWithMetaInfo_1 = __importDefault(require("../../generated/joynr/types/DiscoveryEntryWithMetaInfo"));
const UtilInternal = __importStar(require("../util/UtilInternal"));
const nanoid_1 = require("nanoid");
const LoggingManager_1 = __importDefault(require("../system/LoggingManager"));
const defaultWebSocketSettings_1 = __importDefault(require("./settings/defaultWebSocketSettings"));
const defaultLibjoynrSettings_1 = __importDefault(require("./settings/defaultLibjoynrSettings"));
const JoynrMessage_1 = __importDefault(require("../../joynr/messaging/JoynrMessage"));
const JoynrRuntime_1 = __importDefault(require("./JoynrRuntime"));
const JoynrStates = require("./JoynrStates");
const LocalDiscoveryAggregator = require("../capabilities/discovery/LocalDiscoveryAggregator");
const InProcessMessagingSkeleton_1 = __importDefault(require("../messaging/inprocess/InProcessMessagingSkeleton"));
const InProcessMessagingStub_1 = __importDefault(require("../messaging/inprocess/InProcessMessagingStub"));
const log = LoggingManager_1.default.getLogger("joynr.start.WebSocketLibjoynrRuntime");
/**
 * The WebSocketLibjoynrRuntime is the version of the libjoynr-js runtime that communicates with
 * a cluster controller via a WebSocket. The cluster controller is the WebSocket Server, and the
 * libjoynr connects to it with a single websocket for all communication.
 *
 * @name WebSocketLibjoynrRuntime
 * @constructor
 */
class WebSocketLibjoynrRuntime extends JoynrRuntime_1.default {
    constructor(onFatalRuntimeError) {
        super(onFatalRuntimeError);
        this.signingCallback = this.signingCallback.bind(this);
    }
    signingCallback() {
        return this.bufferedOwnerId;
    }
    /**
     * Starts up the libjoynr instance
     *
     * @param {WebSocketLibjoynrProvisioning} provisioning
     * @returns an A+ promise object, reporting when libjoynr startup is
     *          completed or has failed
     * @throws {Error} if libjoynr is not in SHUTDOWN state
     */
    async start(provisioning) {
        super.start(provisioning);
        if (UtilInternal.checkNullUndefined(provisioning.ccAddress)) {
            throw new Error("ccAddress not set in provisioning.ccAddress");
        }
        const keychain = provisioning.keychain;
        if (keychain) {
            if (UtilInternal.checkNullUndefined(keychain.tlsCert)) {
                throw new Error("tlsCert not set in keychain.tlsCert");
            }
            if (UtilInternal.checkNullUndefined(keychain.tlsKey)) {
                throw new Error("tlsKey not set in keychain.tlsKey");
            }
            if (UtilInternal.checkNullUndefined(keychain.tlsCa)) {
                throw new Error("tlsCa not set in keychain.tlsCa");
            }
            if (UtilInternal.checkNullUndefined(keychain.ownerId)) {
                throw new Error("ownerId not set in keychain.ownerId");
            }
            this.bufferedOwnerId = Buffer.from(keychain.ownerId);
            JoynrMessage_1.default.setSigningCallback(this.signingCallback);
            keychain.checkServerIdentity = function (server) {
                if (provisioning.ccAddress.host === server) {
                    return undefined;
                }
                else {
                    throw new Error(`message from unknown host: ${server} on accepted host is cc: ${provisioning.ccAddress.host}.`);
                }
            };
        }
        const initialRoutingTable = {};
        let untypedCapabilities = this.provisioning.capabilities || [];
        const defaultCapabilities = defaultLibjoynrSettings_1.default.capabilities || [];
        untypedCapabilities = untypedCapabilities.concat(defaultCapabilities);
        const protocol = provisioning.ccAddress.protocol || defaultWebSocketSettings_1.default.protocol;
        const ccAddress = new WebSocketAddress_1.default({
            protocol: WebSocketProtocol[protocol.toUpperCase()],
            host: provisioning.ccAddress.host,
            port: provisioning.ccAddress.port,
            path: provisioning.ccAddress.path || defaultWebSocketSettings_1.default.path
        });
        const typedCapabilities = [];
        for (let i = 0; i < untypedCapabilities.length; i++) {
            const capability = new DiscoveryEntryWithMetaInfo_1.default(untypedCapabilities[i]);
            initialRoutingTable[capability.participantId] = ccAddress;
            typedCapabilities.push(capability);
        }
        const localAddress = new WebSocketClientAddress_1.default({
            id: nanoid_1.nanoid()
        });
        this.sharedWebSocket = new SharedWebSocket_1.default({
            remoteAddress: ccAddress,
            localAddress,
            provisioning: provisioning.websocket || {},
            keychain
        });
        this.webSocketMessagingSkeleton = new WebSocketMessagingSkeleton_1.default({
            sharedWebSocket: this.sharedWebSocket,
            mainTransport: true
        });
        const messagingStubFactories = {};
        messagingStubFactories[InProcessAddress_1.default._typeName] = new InProcessMessagingStubFactory_1.default();
        messagingStubFactories[WebSocketAddress_1.default._typeName] = new WebSocketMessagingStubFactory_1.default({
            address: ccAddress,
            sharedWebSocket: this.sharedWebSocket
        });
        const messagingStubFactory = new MessagingStubFactory_1.default({
            messagingStubFactories
        });
        const messageRouterSettings = {
            initialRoutingTable,
            messagingStubFactory,
            multicastAddressCalculator: new WebSocketMulticastAddressCalculator_1.default({
                globalAddress: ccAddress
            }),
            parentMessageRouterAddress: ccAddress,
            incomingAddress: localAddress
        };
        const localDiscoveryAggregator = new LocalDiscoveryAggregator();
        await super.initializePersistency(provisioning);
        super.createMessageRouter(provisioning, messageRouterSettings);
        const clusterControllerMessagingSkeleton = new InProcessMessagingSkeleton_1.default();
        const clusterControllerMessagingStub = new InProcessMessagingStub_1.default(clusterControllerMessagingSkeleton);
        clusterControllerMessagingSkeleton.registerListener(this.messageRouter.route);
        super.initializeComponents(provisioning, localDiscoveryAggregator, clusterControllerMessagingStub, typedCapabilities);
        this.webSocketMessagingSkeleton.registerListener(this.messageRouter.route);
        const internalMessagingQos = new MessagingQos_1.default({ ttl: MessagingQos_1.default.DEFAULT_TTL + 10000 });
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        return this.proxyBuilder.build(RoutingProxy_1.default, {
            domain: "io.joynr",
            messagingQos: internalMessagingQos,
            discoveryQos: new DiscoveryQos_1.default({
                discoveryScope: DiscoveryScope_1.default.LOCAL_ONLY
            }),
            staticArbitration: true
        })
            .then(newRoutingProxy => {
            return this.messageRouter.setRoutingProxy(newRoutingProxy);
        })
            .catch((error) => {
            throw new Error(`Failed to create routing proxy: ${error}`);
        })
            .then(() => {
            return this.messageRouter.configureReplyToAddressFromRoutingProxy();
        })
            .catch((error) => {
            throw new Error(`Failed to initialize replyToAddress: ${error}`);
        })
            .then(() => {
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            return this.proxyBuilder.build(DiscoveryProxy_1.default, {
                domain: "io.joynr",
                messagingQos: internalMessagingQos,
                discoveryQos: new DiscoveryQos_1.default({
                    discoveryScope: DiscoveryScope_1.default.LOCAL_ONLY
                }),
                staticArbitration: true
            });
        })
            .then((newDiscoveryProxy) => {
            localDiscoveryAggregator.setDiscoveryProxy(newDiscoveryProxy);
            this.joynrState = JoynrStates.STARTED;
            log.debug("joynr web socket initialized");
        })
            .catch(async (error) => {
            log.error(`error starting up joynr: ${error}`);
            await this.shutdown();
            throw error;
        });
    }
    /**
     *  Sends subscriptionStop messages for all active subscriptions.
     *
     *  @param timeout {number} optional timeout defaulting to 0 = no timeout
     *  @returns - resolved after all SubscriptionStop messages are sent.
     *  - rejected in case of any issues or timeout occurs.
     */
    terminateAllSubscriptions(timeout = 0) {
        this.sharedWebSocket.enableShutdownMode();
        return super.terminateAllSubscriptions(timeout);
    }
    /**
     * Shuts down libjoynr
     * @param settings.clearSubscriptionsTimeoutMs {number} time in ms till clearSubscriptionsPromise will be rejected
     *  if it's not resolved yet
     * @param settings.clearSubscriptionsEnabled {boolean} clear all subscriptions before shutting down.
     *  Set this to false in process.exit handler as this is not synchronous.
     *
     * @returns - resolved after successful shutdown
     * - rejected in case of any issues
     */
    async shutdown(settings) {
        if (this.sharedWebSocket) {
            this.sharedWebSocket.enableShutdownMode();
        }
        await super.shutdown(settings);
        if (this.webSocketMessagingSkeleton !== null) {
            this.webSocketMessagingSkeleton.shutdown();
        }
    }
}
module.exports = WebSocketLibjoynrRuntime;
