"use strict";
/*
 * #%L
 * %%
 * Copyright (C) 2019 BMW Car IT GmbH
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/* istanbul ignore file */
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * @exports DiagnosticTags
 */
const UtilInternal = __importStar(require("../util/UtilInternal"));
const LoggingManager_1 = __importDefault(require("./LoggingManager"));
/**
 * @param joynrMessage
 * @returns object to be logged
 */
function forJoynrMessage(joynrMessage) {
    return {
        diagnosticTag: "JoynrMessage",
        from: joynrMessage.from,
        to: joynrMessage.to,
        type: joynrMessage.type
    };
}
exports.forJoynrMessage = forJoynrMessage;
/**
 * @param channelInfo.channelUrl
 * @param channelInfo.channelId
 * @param channelInfo.status
 * @param channelInfo.responseText
 */
function forChannel(channelInfo) {
    return {
        diagnosticTag: "ChannelInfo",
        channelUrl: channelInfo.channelUrl,
        channelId: channelInfo.channelId,
        status: channelInfo.status,
        responseText: channelInfo.responseText
    };
}
exports.forChannel = forChannel;
let forRequestHelper = (tagsForRequest, requestInfo) => {
    if (requestInfo.request.params) {
        tagsForRequest.params = requestInfo.request.params;
    }
};
/**
 * @param requestInfo
 */
function forRequest(requestInfo) {
    const tagsForRequest = {
        diagnosticTag: "Request",
        requestReplyId: requestInfo.request.requestReplyId,
        to: requestInfo.to,
        from: requestInfo.from
    };
    forRequestHelper(tagsForRequest, requestInfo);
    return tagsForRequest;
}
exports.forRequest = forRequest;
let forOneWayRequestHelper = (tagsForOneWayRequest, requestInfo) => {
    if (requestInfo.request.params) {
        tagsForOneWayRequest.params = requestInfo.request.params;
    }
};
/**
 * @param requestInfo
 */
function forOneWayRequest(requestInfo) {
    const tagsForOneWayRequest = {
        diagnosticTag: "OneWayRequest",
        to: requestInfo.to,
        from: requestInfo.from
    };
    forOneWayRequestHelper(tagsForOneWayRequest, requestInfo);
    return tagsForOneWayRequest;
}
exports.forOneWayRequest = forOneWayRequest;
let forReplyHelper = (tagsForReply, replyInfo) => {
    tagsForReply.response = replyInfo.reply.response;
};
/**
 * @param replyInfo
 */
function forReply(replyInfo) {
    const tagsForReply = {
        diagnosticTag: "Reply",
        requestReplyId: replyInfo.reply.requestReplyId,
        to: replyInfo.to,
        from: replyInfo.from
    };
    if (replyInfo.reply.error) {
        tagsForReply.error = replyInfo.reply.error;
    }
    forReplyHelper(tagsForReply, replyInfo);
    return tagsForReply;
}
exports.forReply = forReply;
/**
 * @param subscriptionReplyInfo
 */
function forSubscriptionReply(subscriptionReplyInfo) {
    const subscriptionReplyTag = {
        diagnosticTag: "SubscriptionReply",
        subscriptionId: subscriptionReplyInfo.subscriptionReply.subscriptionId,
        to: subscriptionReplyInfo.to,
        from: subscriptionReplyInfo.from
    };
    if (subscriptionReplyInfo.subscriptionReply.error) {
        subscriptionReplyTag.error = subscriptionReplyInfo.subscriptionReply.error;
    }
    return subscriptionReplyTag;
}
exports.forSubscriptionReply = forSubscriptionReply;
/**
 * @param subscriptionRequestInfo
 */
function forMulticastSubscriptionRequest(subscriptionRequestInfo) {
    return {
        diagnosticTag: "MulticastSubscriptionRequest",
        eventName: subscriptionRequestInfo.subscriptionRequest.subscribedToName,
        subscriptionId: subscriptionRequestInfo.subscriptionRequest.subscriptionId,
        multicastId: subscriptionRequestInfo.subscriptionRequest.multicastId,
        to: subscriptionRequestInfo.to,
        from: subscriptionRequestInfo.from
    };
}
exports.forMulticastSubscriptionRequest = forMulticastSubscriptionRequest;
/**
 * @param subscriptionRequestInfo
 */
function forBroadcastSubscriptionRequest(subscriptionRequestInfo) {
    return {
        diagnosticTag: "BroadcastSubscriptionRequest",
        eventName: subscriptionRequestInfo.subscriptionRequest.subscribedToName,
        subscriptionId: subscriptionRequestInfo.subscriptionRequest.subscriptionId,
        to: subscriptionRequestInfo.to,
        from: subscriptionRequestInfo.from
    };
}
exports.forBroadcastSubscriptionRequest = forBroadcastSubscriptionRequest;
/**
 * @param subscriptionRequestInfo
 */
function forSubscriptionRequest(subscriptionRequestInfo) {
    return {
        diagnosticTag: "SubscriptionRequest",
        attributeName: subscriptionRequestInfo.subscriptionRequest.subscribedToName,
        subscriptionId: subscriptionRequestInfo.subscriptionRequest.subscriptionId,
        to: subscriptionRequestInfo.to,
        from: subscriptionRequestInfo.from
    };
}
exports.forSubscriptionRequest = forSubscriptionRequest;
/**
 * @param subscriptionStopInfo
 */
function forSubscriptionStop(subscriptionStopInfo) {
    return {
        diagnosticTag: "SubscriptionStop",
        subscriptionId: subscriptionStopInfo.subscriptionId,
        to: subscriptionStopInfo.to,
        from: subscriptionStopInfo.from
    };
}
exports.forSubscriptionStop = forSubscriptionStop;
let forPublicationHelper = (tagsForPublication, publicationInfo) => {
    tagsForPublication.response = publicationInfo.publication.response;
};
/**
 * @param publicationInfo
 */
function forPublication(publicationInfo) {
    const tagsForPublication = {
        diagnosticTag: "Publication",
        subscriptionId: publicationInfo.publication.subscriptionId,
        to: publicationInfo.to,
        from: publicationInfo.from
    };
    forPublicationHelper(tagsForPublication, publicationInfo);
    if (publicationInfo.error) {
        tagsForPublication.error = publicationInfo.error;
    }
    return tagsForPublication;
}
exports.forPublication = forPublication;
let forMulticastPublicationHelper = (tagsForMulticastPublication, publicationInfo) => {
    tagsForMulticastPublication.response = publicationInfo.publication.response;
};
/**
 * @param publicationInfo - multicast publication info
 */
function forMulticastPublication(publicationInfo) {
    const tagsForMulticastPublication = {
        diagnosticTag: "MulticastPublication",
        multicastId: publicationInfo.publication.multicastId,
        from: publicationInfo.from
    };
    forMulticastPublicationHelper(tagsForMulticastPublication, publicationInfo);
    if (publicationInfo.error) {
        tagsForMulticastPublication.error = publicationInfo.error;
    }
    return tagsForMulticastPublication;
}
exports.forMulticastPublication = forMulticastPublication;
function logLevelChangedCb(level) {
    if (level !== LoggingManager_1.default.LogLevel.DEBUG && level !== LoggingManager_1.default.LogLevel.TRACE) {
        forRequestHelper = UtilInternal.emptyFunction;
        forOneWayRequestHelper = UtilInternal.emptyFunction;
        forReplyHelper = UtilInternal.emptyFunction;
        forPublicationHelper = UtilInternal.emptyFunction;
        forMulticastPublicationHelper = UtilInternal.emptyFunction;
    }
}
LoggingManager_1.default.registerForLogLevelChanged(logLevelChangedCb);
