export declare type LogLevel = "trace" | "debug" | "info" | "warn" | "error" | "fatal" | "off";
declare type LoggingFunction = (message: string, object?: any) => void;
export interface LoggingEvent {
    level: {
        name: string;
    };
    messages: string[];
}
/**
 * JoynrLogger can be instantiated before any settings are done. The settings will later on be set
 * only once for JoynrLogger, which will then apply it for all members. This process is being done
 * by editing the prototype. A factory pattern would do this potentially in a cleaner way, but this
 * class was heavily optimized for performance and any changes would bring more overhead.
 *
 * Typescript doesn't allow access direct access to the prototype and doesn't understand how the
 * prototype is manipulated. Thus there are multiple @ts-ignore statements.
 */
export default class JoynrLogger {
    static LogLevel: Record<string, LogLevel>;
    private name;
    trace: LoggingFunction;
    debug: LoggingFunction;
    info: LoggingFunction;
    warn: LoggingFunction;
    error: LoggingFunction;
    fatal: LoggingFunction;
    private static trace;
    private static debug;
    private static info;
    private static warn;
    private static error;
    private static fatal;
    private static level;
    private static output;
    private log;
    private format?;
    constructor(name?: string);
    isDebugEnabled(): boolean;
    static setLogLevel(level: LogLevel): void;
    private static logWithoutFormatting;
    private static logWithFormatting;
    static setOutput(outputFunction: Function): void;
    static setFormatting(pattern: string): void;
    private static createFormattingFunctionFromSteps;
    private static createLog;
}
export {};
