"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
const ConsoleAppenderNode_1 = __importDefault(require("./ConsoleAppenderNode"));
const JoynrLogger_1 = __importDefault(require("./JoynrLogger"));
const UtilInternal = __importStar(require("../util/UtilInternal"));
const logLevelChangedCallbacks = [];
class LoggingManager {
    constructor() {
        this.LogLevel = JoynrLogger_1.default.LogLevel;
    }
    reset() {
        JoynrLogger_1.default.setOutput(ConsoleAppenderNode_1.default.prototype.append);
    }
    /**
     * @param name - the name of the logger
     *
     * @returns a new Instance of JoynrLogger with the respective name.
     */
    getLogger(name) {
        return new JoynrLogger_1.default(name);
    }
    /**
     * configure takes a configuration object that conforms to a subset of the log4j2
     * json configuration
     *
     * @param settings - log4j2-style JSON config, but as JavaScript object
     *            (i.e. already parsed)
     */
    configure(settings) {
        const settingsProxy = UtilInternal.augmentConfig(settings);
        const level = settingsProxy.configuration.loggers.root.level();
        if (level) {
            JoynrLogger_1.default.setLogLevel(level);
            logLevelChangedCallbacks.forEach((callback) => {
                callback(level);
            });
        }
        const patternLayout = settingsProxy.configuration.appenders.appender[0].PatternLayout.pattern();
        if (patternLayout && patternLayout !== "%m") {
            JoynrLogger_1.default.setFormatting(patternLayout);
        }
        if (settings.appenderClasses && Object.keys(settings.appenderClasses).length > 0) {
            const appenderClassKey = Object.keys(settings.appenderClasses)[0];
            JoynrLogger_1.default.setOutput(settings.appenderClasses[appenderClassKey].prototype.append);
        }
    }
    registerForLogLevelChanged(callback) {
        logLevelChangedCallbacks.push(callback);
    }
}
const loggingManager = new LoggingManager();
loggingManager.reset();
module.exports = loggingManager;
