import DiscoveryEntry from "../../generated/joynr/types/DiscoveryEntry";
import GlobalDiscoveryEntry from "../../generated/joynr/types/GlobalDiscoveryEntry";
import DiscoveryEntryWithMetaInfo from "../../generated/joynr/types/DiscoveryEntryWithMetaInfo";
/**
 * This method transforms a capabilityInformation into an object of type "DiscoveryEntry"
 *
 * @param capabilityInformation the object to be transformed
 *
 * @returns the transformed object
 */
export declare function toDiscoveryEntry(capabilityInformation: any): DiscoveryEntry;
/**
 * This method transforms an array of capabilityInformations into an array of objects
 * of type DiscoveryEntry
 *
 * @param capabilityInformations array of capability information
 *
 * @returns array of transformed objects of type DiscoveryEntry
 */
export declare function toDiscoveryEntries(capabilityInformations: any[]): DiscoveryEntry[];
/**
 * This method transforms a DiscoveryEntry into a GlobalDiscoveryEntry
 * with the given address.
 *
 * @param discoveryEntry the DiscoveryEntry to be transformed
 * @param address the address to be used for the GlobalDiscoveryEntry
 *
 * @returns global DiscoveryEntry with provided address
 */
export declare function discoveryEntry2GlobalDiscoveryEntry(discoveryEntry: DiscoveryEntry, address: any): GlobalDiscoveryEntry;
/**
 * This method transforms a DiscoveryEntry into a DiscoveryEntryWithMetaInfo
 * with the given isLocal value.
 *
 * @param isLocal true, if it is a local DiscoveryEntry, false otherwise
 * @param discoveryEntry the DiscoveryEntry to be transformed
 *
 * @returns DiscoveryEntryWithMetaInfo with the given isLocal value
 */
export declare function convertToDiscoveryEntryWithMetaInfo(isLocal: boolean, discoveryEntry: DiscoveryEntry): DiscoveryEntryWithMetaInfo;
/**
 * This method transforms an array of DiscoveryEntries into an array of objects
 * of type DiscoveryEntryWithMetaInfo
 *
 * @param isLocal true, if the DiscoveryEntries are local DiscoveryEntry, false otherwise
 * @param discoveryEntries array of DiscoveryEntries
 *
 * @returns array of transformed objects of type DiscoveryEntryWithMetaInfo with the given isLocal value
 */
export declare function convertToDiscoveryEntryWithMetaInfoArray(isLocal: boolean, discoveryEntries: any[]): any[];
/**
 * This method generates a key of the currently used format for storage of
 * a capability's participantId in the ParticipantIdStorage
 *
 * @param domain the domain of the capability that is to be stored
 * @param interfaceName the interface of the capability that is to be stored
 * @param majorVersion the major Version of the capability that is to be stored
 *
 * @returns a key to store the participantId with
 */
export declare function generateParticipantIdStorageKey(domain: string, interfaceName: string, majorVersion: number): string;
