/**
 * Implementation for long (>2^31-1 ms) timer functions that only allows timeouts or intervals
 * of 2^31-1 ms (because of SignedInt32 representation)
 */
declare class LongTimer {
    readonly maxTime: number;
    readonly idPrefix: string;
    private timeoutMap;
    private highestTimeoutId;
    private highestIntervalId;
    private intervalMap;
    /**
     * Implementation for long (>2^31-1 ms) window.setTimeout only allows intervals of 2^31-1 ms
     * (because of SignedInt32 representation)
     *
     * @param func timout handler
     * @param timeout in ms for function to be called
     * @param args extra parameters for func
     * @returns timeout identifier
     * @throws {Error} if parameters are nullable or not of documented type
     */
    setTimeout(func: Function, timeout: number, ...args: any[]): string | number;
    private timeoutPortion;
    /**
     * Clears the timeout
     *
     * @param timeoutId the timeout id given by setTimeout
     * @throws {Error} if parameters are nullable or not of documented type
     */
    clearTimeout(timeoutId: string | number): void;
    /**
     * Implementation for long (>2^31-1 ms) window.setInterval only allows intervals of 2^31-1 ms
     * (because of SignedInt32 representation)
     *
     * @param func
     * @param interval
     * @returns interval identifier
     * @throws {Error} if parameters are nullable or not of documented type
     */
    setInterval(func: Function, interval: number): number;
    /**
     * Clears the interval
     *
     * @param intervalId the interval id given by setInterval
     * @throws {Error} if parameters are nullable or not of documented type
     */
    clearInterval(intervalId: number): void;
}
declare type longTimer = LongTimer;
declare const longTimer: LongTimer;
export = longTimer;
