import { checkProperty, checkPropertyIfDefined, getObjectType } from "./UtilInternal";
export { checkProperty, checkPropertyIfDefined, getObjectType };
export declare function checkPropertyAllowObject(obj: any, type: string, description: string): void;
/**
 * Recursively deep copies a given object and augments type information on the way if a
 * constructor is registered in the typeRegistry for the value of the object's
 * member "_typeName"
 *
 * @param untyped the untyped object
 * @param typeHint optional parameter which provides the type informed of the untyped object.
 *            This is used i.e. for enums, where the type information is not included in the untyped object itself
 * @returns a deep copy of the untyped object with the types being augmented
 * @throws {Error} if in any of the objects contains a member of type "Function" or the type of the
 *             untyped object is not (Boolean|Number|String|Array|Object)
 */
export declare function augmentTypes(untyped: any, typeHint?: string): any;
/**
 * Augments the javascript runtime type into the member "_typeName"
 *
 * @param obj the object to augment the typeName for
 * @param [packageName] an optional packageName that is used as starting string for
 *             _typeName
 * @param [memberName] an optional member name that is used instead of _typeName
 *
 * @returns the same object with the typeName set
 */
export declare function augmentTypeName(obj: any, packageName?: string, memberName?: string): any;
/**
 * Returns true if the object is a joynr complex type modelled in Franca
 */
export declare function isComplexJoynrObject(value: any): boolean;
/**
 * Returns true if the object is a joynr enum type modelled in Franca
 * @param value the object to be check for typing
 * @param checkForJoynrObject an optional member. If set to true,
 *                  the parameter value is forced to be an instance of the root
 *                  joynr object type
 * @returns true if the provided value is an enum type
 */
export declare function isEnumType(value: any, checkForJoynrObject?: boolean): boolean;
