/**
 * Copies all attributes to a given out parameter from optional in parameters
 * @function UtilInternal#extend
 */
export declare function extend(out: any, ...args: any[]): any;
/**
 * Forwards all methods from provider to receiver and thus creating privacy
 * @param receiver
 * @param provider
 * @returns
 */
export declare function forward(receiver: any, provider: any): any;
/**
 * Deeply copies all attributes to a given out parameter from optional in parameters
 * @function UtilInternal#extendDeep
 */
export declare function extendDeep<T>(out: T, ...args: any[]): T;
/**
 * Transforms the incoming array "from" according to the transformFunction
 * @function UtilInternal#transform
 */
export declare function transform(from: any[], transformFunction: Function): any[];
/**
 * Checks explicitly if value is null or undefined, use if you don't want !!"" to become false,
 * but !UtilInternal.checkNullUndefined("") to be true
 *
 * @param value the value to be checked for null or undefined
 * @returns if the value is null or undefined
 */
export declare function checkNullUndefined(value: any): boolean;
/**
 * Converts the first character of the string to lower case
 * @function UtilInternal#firstLower
 *
 * @param str the string to be converted
 * @returns the converted string
 * @throws {TypeError} on nullable input (null, undefined)
 */
export declare function firstLower(str: string): string;
/**
 * Capitalizes the first letter
 * @function UtilInternal#firstUpper
 *
 * @param str the string to be converted
 * @returns the converted string
 * @throws {TypeError} on nullable input (null, undefined)
 */
export declare function firstUpper(str: string): string;
/**
 * Checks if the provided argument is an A+ promise object
 *
 * @param arg the argument to be evaluated
 * @returns true if provided argument is a promise, otherwise false
 */
export declare function isPromise(arg: any): boolean;
/**
 * Shorthand function for Object.defineProperty
 *
 * @param object
 * @param memberName
 * @param value default value is undefined
 * @param writable default value is false
 * @param enumerable default value is true
 * @param configurable default value is false
 */
export declare function objectDefineProperty(object: object, memberName: string, value: any, writable: boolean, enumerable: boolean, configurable: boolean): void;
/**
 * Returns the byte length of the provided string encoded in UTF-8
 *
 * @param text as UTF-8 encoded string
 * @returns the length in bytes
 */
export declare function getLengthInBytes(text: string): number;
/**
 * Returns the max supported long value. According to the ECMA spec this is 2^53 -1 See
 * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/MAX_SAFE_INTEGER
 *
 * Actually this should be Math.pow(2, 63) - 1, but this evaluates to 9223372036854776000
 * instead of 9223372036854775808, which is larger than Long.MAX_VALUE of 2^63-1 and wraps
 * around to negative values in Java and will cause problems in C++ too
 *
 */
export declare function getMaxLongValue(): number;
/**
 * Removes item from array
 * @param array to be edited
 * @param item to be removed
 */
export declare function removeElementFromArray(array: any[], item: any): void;
/**
 * Invokes all callbacks with the provided data
 * @param callbacks to be invoked
 * @param data provided as callback argument
 * @param data.broadcastOutputParameters broadcasts output params
 * @param data.filters filter array provided as callback argument
 */
export declare function fire(callbacks: Function[], data: any): void;
export declare const timeoutPromise: (arg1: Promise<any>, arg2: number) => Promise<any>;
export interface Deferred {
    resolve: (value?: any) => void;
    reject: (error?: any) => void;
    promise: Promise<any>;
}
export declare function createDeferred(): Deferred;
/**
 *
 * Create an ES6 Proxy Object to facilitate access of nested properties.
 *
 * @param config
 * @returns an ES6 Proxy object
 */
export declare function augmentConfig(config: any): any;
export declare function emptyFunction(): void;
export declare function checkProperty(obj: any, type: string | string[] | Function, description: string): void;
/**
 * Checks if the variable is of specified type
 *
 * @param obj the object
 * @param type a string representation of the the data type (e.g. "Boolean", "Number",
 *             "String", "Array", "Object", "Function"
 *            "MyCustomType", "Object|MyCustomType") or a constructor function to check against
 *             using instanceof (e.g. obj
 *            instanceof type)
 * @param description a description for the thrown error
 * @throws an
 *             error if the object not of the given type
 */
export declare function checkPropertyIfDefined(obj: any, type: string | string[] | Function, description: string): void;
/**
 * @param obj the object to determine the type of
 * @returns the object type
 */
export declare function getObjectType(obj: any): string;
