"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * #%L
 * %%
 * Copyright (C) 2011 - 2017 BMW Car IT GmbH
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
const LongTimer_1 = __importDefault(require("./LongTimer"));
const util_1 = __importDefault(require("util"));
/* istanbul ignore file */
function extendInternal(to, from, deep) {
    if (from) {
        for (const key in from) {
            if (Object.prototype.hasOwnProperty.call(from, key)) {
                if (deep && typeof from[key] === "object") {
                    if (Array.isArray(from[key]) && !Array.isArray(to[key])) {
                        to[key] = [];
                    }
                    else if (typeof to[key] !== "object") {
                        to[key] = {};
                    }
                    extendInternal(to[key], from[key], deep);
                }
                else if (from[key] !== undefined) {
                    to[key] = from[key];
                }
            }
        }
    }
    return to;
}
/**
 * Copies all attributes to a given out parameter from optional in parameters
 * @function UtilInternal#extend
 */
function extend(out, ...args) {
    for (let i = 0; i < args.length; i++) {
        extendInternal(out, args[i], false);
    }
    return out;
}
exports.extend = extend;
/**
 * Forwards all methods from provider to receiver and thus creating privacy
 * @param receiver
 * @param provider
 * @returns
 */
function forward(receiver, provider) {
    let methodName;
    for (methodName in provider) {
        if (Object.prototype.hasOwnProperty.call(provider, methodName) && typeof provider[methodName] === "function") {
            receiver[methodName] = provider[methodName].bind(provider);
        }
    }
    return receiver;
}
exports.forward = forward;
/**
 * Deeply copies all attributes to a given out parameter from optional in parameters
 * @function UtilInternal#extendDeep
 */
function extendDeep(out, ...args) {
    for (let i = 0; i < args.length; i++) {
        extendInternal(out, args[i], true);
    }
    return out;
}
exports.extendDeep = extendDeep;
/**
 * Transforms the incoming array "from" according to the transformFunction
 * @function UtilInternal#transform
 */
function transform(from, transformFunction) {
    const transformedArray = [];
    for (let i = 0; i < from.length; i++) {
        const value = from[i];
        transformedArray.push(transformFunction(value, i));
    }
    return transformedArray;
}
exports.transform = transform;
/**
 * Checks explicitly if value is null or undefined, use if you don't want !!"" to become false,
 * but !UtilInternal.checkNullUndefined("") to be true
 *
 * @param value the value to be checked for null or undefined
 * @returns if the value is null or undefined
 */
function checkNullUndefined(value) {
    return value === null || value === undefined;
}
exports.checkNullUndefined = checkNullUndefined;
/**
 * Converts the first character of the string to lower case
 * @function UtilInternal#firstLower
 *
 * @param str the string to be converted
 * @returns the converted string
 * @throws {TypeError} on nullable input (null, undefined)
 */
function firstLower(str) {
    return str.substr(0, 1).toLowerCase() + str.substr(1);
}
exports.firstLower = firstLower;
/**
 * Capitalizes the first letter
 * @function UtilInternal#firstUpper
 *
 * @param str the string to be converted
 * @returns the converted string
 * @throws {TypeError} on nullable input (null, undefined)
 */
function firstUpper(str) {
    return str.substr(0, 1).toUpperCase() + str.substr(1);
}
exports.firstUpper = firstUpper;
/**
 * Checks if the provided argument is an A+ promise object
 *
 * @param arg the argument to be evaluated
 * @returns true if provided argument is a promise, otherwise false
 */
function isPromise(arg) {
    return arg !== undefined && typeof arg.then === "function" && typeof arg.catch === "function";
}
exports.isPromise = isPromise;
/**
 * Shorthand function for Object.defineProperty
 *
 * @param object
 * @param memberName
 * @param value default value is undefined
 * @param writable default value is false
 * @param enumerable default value is true
 * @param configurable default value is false
 */
function objectDefineProperty(object, memberName, value, writable, enumerable, configurable) {
    Object.defineProperty(object, memberName, {
        value,
        writable: writable === undefined ? false : writable,
        enumerable: enumerable === undefined ? true : enumerable,
        configurable: configurable === undefined ? false : configurable
    });
}
exports.objectDefineProperty = objectDefineProperty;
/**
 * Returns the byte length of the provided string encoded in UTF-8
 *
 * @param text as UTF-8 encoded string
 * @returns the length in bytes
 */
function getLengthInBytes(text) {
    // blob is twice as fast, and unescape is actually deprecated
    //return new Blob([text]).size;
    return unescape(encodeURIComponent(text)).length;
}
exports.getLengthInBytes = getLengthInBytes;
/**
 * Returns the max supported long value. According to the ECMA spec this is 2^53 -1 See
 * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/MAX_SAFE_INTEGER
 *
 * Actually this should be Math.pow(2, 63) - 1, but this evaluates to 9223372036854776000
 * instead of 9223372036854775808, which is larger than Long.MAX_VALUE of 2^63-1 and wraps
 * around to negative values in Java and will cause problems in C++ too
 *
 */
function getMaxLongValue() {
    return Number.MAX_SAFE_INTEGER;
}
exports.getMaxLongValue = getMaxLongValue;
/**
 * Removes item from array
 * @param array to be edited
 * @param item to be removed
 */
function removeElementFromArray(array, item) {
    const i = array.indexOf(item);
    if (i > -1) {
        array.splice(i, 1);
    }
}
exports.removeElementFromArray = removeElementFromArray;
/**
 * Invokes all callbacks with the provided data
 * @param callbacks to be invoked
 * @param data provided as callback argument
 * @param data.broadcastOutputParameters broadcasts output params
 * @param data.filters filter array provided as callback argument
 */
function fire(callbacks, data) {
    let callbackFct;
    for (callbackFct in callbacks) {
        if (Object.prototype.hasOwnProperty.call(callbacks, callbackFct)) {
            callbacks[callbackFct](data);
        }
    }
}
exports.fire = fire;
function timeoutPromiseHelper(promise, timeoutMs, callback) {
    const timeout = LongTimer_1.default.setTimeout(() => {
        callback(new Error(`Promise timeout after ${timeoutMs} ms`), undefined);
    }, timeoutMs);
    promise
        .then((...args) => {
        LongTimer_1.default.clearTimeout(timeout);
        // eslint-disable-next-line promise/no-callback-in-promise
        callback(undefined, ...args);
    })
        // eslint-disable-next-line promise/no-callback-in-promise
        .catch(callback);
}
exports.timeoutPromise = util_1.default.promisify(timeoutPromiseHelper);
function defer(resolve, reject) {
    this.resolve = resolve;
    this.reject = reject;
}
function createDeferred() {
    const deferred = {};
    /*eslint-disable promise/avoid-new */
    deferred.promise = new Promise(defer.bind(deferred));
    /*eslint-enable promise/avoid-new */
    return deferred;
}
exports.createDeferred = createDeferred;
/**
 *
 * Create an ES6 Proxy Object to facilitate access of nested properties.
 *
 * @param config
 * @returns an ES6 Proxy object
 */
function augmentConfig(config) {
    let parts = [];
    const proxy = new Proxy(() => {
        let level = config;
        for (let i = 0; i < parts.length; i++) {
            if (level === undefined) {
                parts = [];
                return undefined;
            }
            level = level[parts[i]];
        }
        parts = [];
        return level;
    }, {
        has() {
            return true;
        },
        get(_, prop) {
            parts.push(prop);
            return proxy;
        },
        set(_, prop, value) {
            let level = config;
            for (let i = 0; i < parts.length; i++) {
                if (!Object.prototype.hasOwnProperty.call(level, parts[i])) {
                    level[parts[i]] = {};
                }
                level = level[parts[i]];
            }
            parts = [];
            level[prop] = value;
            return true;
        }
    });
    return proxy;
}
exports.augmentConfig = augmentConfig;
function emptyFunction() {
    // do nothing
}
exports.emptyFunction = emptyFunction;
function checkProperty(obj, type, description) {
    if (obj === undefined) {
        throw new Error(`${description} is undefined`);
    }
    const objectType = getObjectType(obj);
    if (typeof type === "string" && objectType !== type) {
        throw new Error(`${description} is not of type ${type}. Actual type is ${objectType}`);
    }
    if (Array.isArray(type) && !objectType.match(`^${type.join("$|^")}$`)) {
        throw new Error(`${description} is not of a type from ${type}. Actual type is ${objectType}`);
    }
    if (typeof type === "function" && !(obj instanceof type)) {
        throw new Error(`${description} is not of type ${getObjectType(type)}. Actual type is ${objectType}`);
    }
}
exports.checkProperty = checkProperty;
/**
 * Checks if the variable is of specified type
 *
 * @param obj the object
 * @param type a string representation of the the data type (e.g. "Boolean", "Number",
 *             "String", "Array", "Object", "Function"
 *            "MyCustomType", "Object|MyCustomType") or a constructor function to check against
 *             using instanceof (e.g. obj
 *            instanceof type)
 * @param description a description for the thrown error
 * @throws an
 *             error if the object not of the given type
 */
function checkPropertyIfDefined(obj, type, description) {
    if (obj !== undefined && obj !== null) {
        checkProperty(obj, type, description);
    }
}
exports.checkPropertyIfDefined = checkPropertyIfDefined;
/**
 * @param obj the object to determine the type of
 * @returns the object type
 */
function getObjectType(obj) {
    if (obj === null || obj === undefined) {
        throw new Error("cannot determine the type of an undefined object");
    }
    if (Array.isArray(obj)) {
        return "Array";
    }
    return obj.constructor.name || "";
}
exports.getObjectType = getObjectType;
