"use strict";
/*
 * #%L
 * %%
 * Copyright (C) 2019 BMW Car IT GmbH
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
const buildSignature_1 = __importDefault(require("./joynr/buildSignature"));
const MessagingQos_1 = __importDefault(require("./joynr/messaging/MessagingQos"));
const PeriodicSubscriptionQos_1 = __importDefault(require("./joynr/proxy/PeriodicSubscriptionQos"));
const OnChangeSubscriptionQos_1 = __importDefault(require("./joynr/proxy/OnChangeSubscriptionQos"));
const MulticastSubscriptionQos_1 = __importDefault(require("./joynr/proxy/MulticastSubscriptionQos"));
const OnChangeWithKeepAliveSubscriptionQos_1 = __importDefault(require("./joynr/proxy/OnChangeWithKeepAliveSubscriptionQos"));
const BroadcastFilterParameters_1 = __importDefault(require("./joynr/proxy/BroadcastFilterParameters"));
const ArbitrationStrategyCollection = __importStar(require("./joynr/types/ArbitrationStrategyCollection"));
const Util = __importStar(require("./joynr/util/Util"));
const JoynrException_1 = __importDefault(require("./joynr/exceptions/JoynrException"));
const JoynrRuntimeException_1 = __importDefault(require("./joynr/exceptions/JoynrRuntimeException"));
const ApplicationException_1 = __importDefault(require("./joynr/exceptions/ApplicationException"));
const DiscoveryException_1 = __importDefault(require("./joynr/exceptions/DiscoveryException"));
const IllegalAccessException_1 = __importDefault(require("./joynr/exceptions/IllegalAccessException"));
const MethodInvocationException_1 = __importDefault(require("./joynr/exceptions/MethodInvocationException"));
const NoCompatibleProviderFoundException_1 = __importDefault(require("./joynr/exceptions/NoCompatibleProviderFoundException"));
const ProviderRuntimeException_1 = __importDefault(require("./joynr/exceptions/ProviderRuntimeException"));
const PublicationMissedException_1 = __importDefault(require("./joynr/exceptions/PublicationMissedException"));
const SubscriptionException_1 = __importDefault(require("./joynr/exceptions/SubscriptionException"));
const ProviderQos_1 = __importDefault(require("./generated/joynr/types/ProviderQos"));
const ProviderScope_1 = __importDefault(require("./generated/joynr/types/ProviderScope"));
const CustomParameter_1 = __importDefault(require("./generated/joynr/types/CustomParameter"));
const DiscoveryQos_1 = __importDefault(require("./joynr/proxy/DiscoveryQos"));
const DiscoveryScope_1 = __importDefault(require("./generated/joynr/types/DiscoveryScope"));
const BrowserAddress_1 = __importDefault(require("./generated/joynr/system/RoutingTypes/BrowserAddress"));
const ChannelAddress_1 = __importDefault(require("./generated/joynr/system/RoutingTypes/ChannelAddress"));
const WebSocketAddress_1 = __importDefault(require("./generated/joynr/system/RoutingTypes/WebSocketAddress"));
const WebSocketClientAddress_1 = __importDefault(require("./generated/joynr/system/RoutingTypes/WebSocketClientAddress"));
const LongTimer_1 = __importDefault(require("./joynr/util/LongTimer"));
/* istanbul ignore file */
class JoynrApi {
    constructor() {
        this.buildSignature = buildSignature_1.default;
        this.messaging = {
            MessagingQos: MessagingQos_1.default
        };
        this.proxy = {
            PeriodicSubscriptionQos: PeriodicSubscriptionQos_1.default,
            OnChangeSubscriptionQos: OnChangeSubscriptionQos_1.default,
            MulticastSubscriptionQos: MulticastSubscriptionQos_1.default,
            OnChangeWithKeepAliveSubscriptionQos: OnChangeWithKeepAliveSubscriptionQos_1.default,
            BroadcastFilterParameters: BroadcastFilterParameters_1.default,
            DiscoveryQos: DiscoveryQos_1.default
        };
        this.types = {
            ArbitrationStrategyCollection,
            ProviderQos: ProviderQos_1.default,
            ProviderScope: ProviderScope_1.default,
            CustomParameter: CustomParameter_1.default,
            DiscoveryScope: DiscoveryScope_1.default
        };
        this.util = { LongTimer: LongTimer_1.default, Util };
        this.exceptions = {
            JoynrException: JoynrException_1.default,
            JoynrRuntimeException: JoynrRuntimeException_1.default,
            ApplicationException: ApplicationException_1.default,
            DiscoveryException: DiscoveryException_1.default,
            IllegalAccessException: IllegalAccessException_1.default,
            MethodInvocationException: MethodInvocationException_1.default,
            NoCompatibleProviderFoundException: NoCompatibleProviderFoundException_1.default,
            ProviderRuntimeException: ProviderRuntimeException_1.default,
            PublicationMissedException: PublicationMissedException_1.default,
            SubscriptionException: SubscriptionException_1.default
        };
        this.system = {
            RoutingTypes: {
                BrowserAddress: BrowserAddress_1.default,
                ChannelAddress: ChannelAddress_1.default,
                WebSocketAddress: WebSocketAddress_1.default,
                WebSocketClientAddress: WebSocketClientAddress_1.default
            }
        };
    }
}
module.exports = JoynrApi;
